<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Main Menu /////////////////////////
// Buttons:
define('MAIN_MENU_CONTENT_HEADING', "kontni");
define('MAIN_MENU_EDIT_PAGE_BTN', "Edit avantou");
define('MAIN_MENU_CREATE_PAGE_BTN', "Kreye Page");
define('MAIN_MENU_MANAGE_BORDER_AREAS_BTN', "Jere Zòn Border");
define('MAIN_MENU_MANAGE_IMAGES_BTN', "jere Imaj");
define('MAIN_MENU_PREVIEW_SITE_BTN', "Preview Pibliye Sit");
define('MAIN_MENU_EDIT_BLOG_BTN', "jere | Edit Blog");
define('MAIN_MENU_EDIT_FILE_BTN', "Edit File");
define('MAIN_MENU_MENUS_HEADING', "meni");
define('MAIN_MENU_EDIT_MENUS_BTN', "Edit Meni");
define('MAIN_MENU_MANAGE_MENUS_BTN', "Jere Devwa Menu");
define('MAIN_MENU_EDIT_CSS_MENU_PARAMS_BTN', "Edit Paramèt CSS-Menu");
define('MAIN_MENU_EDIT_CSS_MENU_STYLES_BTN', "Styles CSS-Menu Edit");
define('MAIN_MENU_EDIT_JS_MENU_PARAMS_BTN', "Paramèt Edit JS-Menu");
define('MAIN_MENU_EDIT_JS_MENU_PARAMS_BTN_ALT', "Paramèt Edit JavaScript-Menu");
define('MAIN_MENU_EDIT_JS_MENU_STYLES_BTN', "Styles Edit JS-Menu");
define('MAIN_MENU_EDIT_JS_MENU_STYLES_BTN_ALT', "Styles Edit JavaScript-Menu");
define('MAIN_MENU_STYLES_HEAD_CONTENT_HEADING', "Styles &amp; HEAD kontni");
define('MAIN_MENU_STYLES_HEAD_CONTENT_HEADING_ALT', "Estil ak HEAD kontni");
define('MAIN_MENU_EDIT_STYLES_BTN', "Styles Edit");
define('MAIN_MENU_EDIT_HEAD_BTN', "Edit Head Kòd");
define('MAIN_MENU_MANAGE_HEAD_BTN', "Jere tèt Kòd");
define('MAIN_MENU_EDIT_FAVICON_BTN', "Edit favikon");
define('MAIN_MENU_PAGE_MANAGEMENT_HEADING', "PAJ MANAGEMENT");
define('MAIN_MENU_EDIT_PAGE_TITLES_BTN', "Edit Page Tit");
define('MAIN_MENU_EDIT_META_TAGS_BTN', "Edit Meta Tags");
define('MAIN_MENU_DELETE_PAGE_BTN', "Debarase m de Page oswa Blog");
define('MAIN_MENU_COPY_RENAME_BTN', "Kopi oswa Chanje non Paj");
define('MAIN_MENU_RESTORE_BTN', "renmèt Page");
define('MAIN_MENU_ADD_PLUGIN_TO_PAGE_BTN', "Enstale Plugin Nan Page");
define('MAIN_MENU_MANAGE_PAGE_ACCESS_BTN', "Jere Page Aksè");
define('MAIN_MENU_MANAGE_PAGE_ATTRIBUTES', "Jere Page Atribi");
define('MAIN_MENU_SITE_MANAGEMENT_HEADING', "Site MANAGEMENT");
define('MAIN_MENU_RERUN_WIZARD_BTN', "Re-kouri Sòsye");
define('MAIN_MENU_UPLOAD_TEMPLATE_BTN', "Voye Modèl");
define('MAIN_MENU_MANAGE_USERS_SITE_OPTIONS_BTN', "Jere Itilizatè yo ak Opsyon Sit");
define('MAIN_MENU_MANAGE_USERS_SITE_OPTIONS_BTN_ALT', "Jere Itilizatè yo ak Opsyon Sit");
define('MAIN_MENU_NEW_SESSION_BTN', "NEW SESYON");
define('MAIN_MENU_LOGOUT_BTN', "DEKONEKTE");
// Console Text:
define('MAIN_MENU_HEADER_DIVIDER', "BREEZE sit entènèt BUILDING MODULE");
// JavaScript Constants
define('MAIN_MENU_TIMEOUT_ERR', "te sesyon ou kwonometre deyò. ou vle ale tounen nan?");

///////////////////////// Login /////////////////////////
// Buttons:
define('LOGIN_LOGIN_BTN', "Ouvri sesyon an");
// Console Text:
define('LOGIN_USERID_PASS_MSG', "Tanpri antre User ID ak Modpas");
define('LOGIN_SAVE_LOGIN_MSG', "Save ouvri sesyon an");
define('LOGIN_FORGOT_PASSWORD_MSG', "Bliye modpas ou?");
define('LOGIN_JS_WARNING_MSG', "AVÈTISMAN SOU: JavaScript yo dwe pèmèt yo sèvi ak sistèm sa a. Tanpri vire sou JavaScipt nan navigatè ou a.");
define('LOGIN_ENTER_EMAIL_MSG', "Tanpri antre Imèl ou a Reyajiste modpas ou");
define('LOGIN_CAPTCHA_MSG', "Tape non an nan oswa karaktè yo ou wè <br /> nan foto a pi wo a <span class='small_message'>(ka sansib)</span>");
// Popup Messages:
define('LOGIN_CAPTCHA_ERR', "antre CAPTCHA ou se kòrèk. Tanpri eseye ankò.");
define('LOGIN_BAD_EMAIL_ERR', "adrès imel la ou te antre nan se pa valab. Tanpri tape nan adrès imel ou ankò.");
define('LOGIN_BAD_REFERER_ERR', "Ou pa parèt yo dwe yon ki valid.");
define('LOGIN_BAD_USER_ERR', "Pa te gen okenn itilizatè jwenn pou imel la. Tanpri re-antre nan adrès imel ou.");
define('LOGIN_PASSWORD_RESET_ERR', "Yon nouvo modpas te voye nan imel ou. Tanpri tcheke imel ou pou mesaj la. Si ou pa jwenn mesaj la, tcheke spambox ou yo.");
define('LOGIN_DEFAULT_ERR', "Yon erè etranj te fèt. Tanpri tcheke pou torche solè.");
define('LOGIN_SSL_WARNING_1', "Remak: Pou navigatè ou a pou konsève pou modpas la, li pral bezwen voye li kode moman sa a. Pou evite pwoblèm sa a, eseye lè l sèvi avèk yon koneksyon SSL chiffres (");
define('LOGIN_SSL_WARNING_2', "). Asire ou ke ou di navigatè ou a nan magazen / mete ajou modpas ou apre ou fin ouvri sesyon an.");
define('LOGIN_EXCEEDED_MAX_ATTEMPTS', "Ou gen depase la pou maksimòm kantite login tantativ. Tanpri kontakte administratè sistèm ou an.");
define('LOGIN_NO_USER_FOUND_ERR', "Pa gen okenn itilizatè pa non sa a. Tanpri re-Entre ID itilizatè ak modpas ou.");
define('LOGIN_NO_USER_FOUND_1_ERR', "Pa gen okenn itilizatè pa non sa a.");
define('LOGIN_NO_USER_FOUND_2_ERR', "yo re-antre non itilizatè ou an ak modpas.");
define('LOGIN_PASSWORD_NOT_CONFIRMED_MSG', "modpas ou a pa te konfime. Tanpri re-antre modpas ou.");
define('LOGIN_PASSWORD_NOT_CONFIRMED_1_MSG', "modpas ou a pa te konfime.");
define('LOGIN_PASSWORD_NOT_CONFIRMED_2_MSG', "yo re-antre modpas ou.");

///////////////////////// Version /////////////////////////
// Console Text:
define('VERSION_DB_PROGRAM_FILE_MISMATCH_MSG', "nivo baz done-revizyon-plak ou a pa koresponn ak nivo pwogram-dosye-revizyon ou yo. Tanpri kontakte administratè sistèm ou an.");
define('VERSION_PROGRAM_FILES_VERSION_MSG', "Pwogram Files Revizyon Nivo");
define('VERSION_DB_VERSION_MSG', "Database Patch Nivo");

///////////////////////// Dashboard /////////////////////////
// Console Text:
define('WELCOME_1_MSG', "Byenveni");
define('WELCOME_2_MSG', "Breeze Sit wèb Builder ™ la. Klike sou nenpòt nan tit yo meni sou bò gòch la jwenn aksè nan zouti yo sistèm pou bati sit entènèt ou.");
define('WELCOME_INSTALL_FOLDER_PRESENT_1_WARNING', "<b>AVÈTISMAN !!!</b> folder enstalasyon ou se toujou prezan sou sèvè a. te kapab Sit ou fasil pou konpwomèt. tanpri klike");
define('WELCOME_INSTALL_FOLDER_PRESENT_2_WARNING', "isit la");
define('WELCOME_INSTALL_FOLDER_PRESENT_3_WARNING', "yo efase <b><em>enstale</em></b> ak <b><em>SQL</em></b> dosye yo soti nan sèvè ou.");
define('WELCOME_LATEST_VERSION_INSTALLED_MSG', "Se vèsyon an dènye nan Breeze Sit wèb Builder ™ a enstale");
define('WELCOME_BETA_VERSION_INSTALLED_1_MSG', "Ou se kounye a kouri vèsyon beta");
define('WELCOME_BETA_VERSION_INSTALLED_2_MSG', "nan Breeze Sit wèb Builder ™ la. aktyèl Lage nan ki estab se");
define('WELCOME_OLD_VERSION_INSTALLED_1_MSG', "Version");
define('WELCOME_OLD_VERSION_INSTALLED_2_MSG', "nan Breeze Sit wèb Builder ™ an ki enstale. Vèsyon an dènye se");
define('WELCOME_OLD_VERSION_INSTALLED_3_MSG', "Klike sou");
define('WELCOME_OLD_VERSION_INSTALLED_5_MSG', "nan download tout nan vèsyon an pita <br /> ajou dosye pase vèsyon ou ye kounye a. Remak: Ou pral bezwen enstale chak nan sa yo dènye sekans jouk enstalasyon ou a se monte-a-dat.");
define('WELCOME_OLD_VERSION_INSTALLED_5A_MSG', "nan download dènye dosye a vèsyon mete yo ajou.");
define('WELCOME_OLD_VERSION_INSTALLED_6_MSG', "Apre ou fin chaje dènye nouvèl sou, klike sou");
define('WELCOME_OLD_VERSION_INSTALLED_6A_MSG', "Apre ou fin chaje aktyalizasyon a, klike sou");
define('WELCOME_OLD_VERSION_INSTALLED_7_MSG', "isit la");
define('WELCOME_OLD_VERSION_INSTALLED_8_MSG', "yo enstale aktyalizasyon a kap vini an.");
define('WELCOME_OLD_VERSION_INSTALLED_8A_MSG', "yo enstale li.");
define('WELCOME_OLD_VERSION_INSTALLED_9_MSG', "Ou pral bezwen yo dwe louvri sesyon an kòm yon administratè yo enstale aktyalizasyon a. Kontakte administratè sistèm ou mete ajou sistèm ou an.");
define('WELCOME_UNKNOWN_VERSION_INSTALLED_1_MSG', "Version");
define('WELCOME_UNKNOWN_VERSION_INSTALLED_2_MSG', "nan Breeze Sit wèb Builder ™ an ki enstale. <span class='extra_small_message'><br /> Remak: Nou pa ka konpare vèsyon ou a ak vèsyon an dènye paske se <b><i>allow_url_fopen</i></b> nan PHP direktiv etenn. Pou ou gen tablodbò sa a tcheke vèsyon ou ak ofri ou ak lyen ki mennen nan dènye nouvèl yo, w ap bezwen yo mete <b><i>allow_url_fopen</i></b> nan <b><i>1</i></b> nan dosye <b><i>php.ini</i></b> ou yo.</span>");
define('WELCOME_PAGE_COUNT', "Page konte:");
define('WELCOME_BLOG_COUNT', "Blog konte:");
define('WELCOME_PLEASE_WAIT_DOWNLOADING_UPDATES_MSG', "Tanpri, tann. Chaje dènye ... Sa a ka pran plizyè minit.");

///////////////////////// Edit Page Select /////////////////////////
// Buttons:
define('EDIT_PAGE_SELECT_HEADING', "Edit avantou");
// Console Text:
define('EDIT_PAGE_SELECT_OPTIONS_HEADING', "editè Opsyon");
define('EDIT_PAGE_SELECT_SOURCE_VIEW_OPTION', "Louvri nan Sous View");
define('EDIT_PAGE_SELECT_MOBILE_STYLE_OPTION', "Sèvi ak Styles mobil");
define('EDIT_PAGE_SELECT_SITE_STYLES_HEADING', "Styles Sit");
define('EDIT_PAGE_SELECT_PAGE_DEFAULT_STYLES_OPTION', "Sèvi ak Page Default");
define('EDIT_PAGE_SELECT_SITE_DEFAULT_STYLES_OPTION', "Sèvi ak sit Styles");
define('EDIT_PAGE_SELECT_DISABLE_SITE_STYLES_OPTION', "Enfim Sit Styles");

/////////////// HTML/JavaScript/PHP/CSS Editor Pages /////////////////
// Buttons:
define('EDITOR_PREVIEW', "Preview");
define('EDITOR_SAVE', "Save");
define('EDITOR_SAVE_AS', "Save Kòm");
define('EDITOR_PUBLISH', "pibliye");
define('EDITOR_REVERT', "retounen");
define('EDITOR_DELETE', "Debarase m de");
define('EDITOR_SEE_SITE', "wè sit");
define('EDITOR_SEE_FILE', "wè File");
define('EDITOR_CLEAR', "Klè");
define('EDITOR_OPTIMIZE_IMAGES', "Optimize Imaj");
define('EDITOR_RESET_IMAGES', "Reyajiste Imaj");
define('EDITOR_EDIT_STYLES', "Styles Edit");
// Console Text:
define('EDITOR_PAGE_NAME', "Page Non");
define('EDITOR_FILE_NAME', "Non dosye");
define('EDITOR_HEAD_NAME', "Head Non");
define('EDITOR_STYLE_SHEET', "Style Fèy");
// Popup Messages:
define('EDITOR_STARTING_UPDATE_MSG', "Koumanse aktyalizasyon ...");
define('EDITOR_PREPARING_PREVIEW_MSG', "Preparasyon aperçu ...");
define('EDITOR_REVERT_BLOG_CONFIRM_1_MSG', "Se asire w ke ou, ou vle retounen <b>id blog</b>");
define('EDITOR_REVERT_BLOG_CONFIRM_2_MSG', "?");
define('EDITOR_REVERT_AREA_CONFIRM_1_MSG', "Èske ou sèten ou vle retounen a");
define('EDITOR_REVERT_AREA_CONFIRM_2_MSG', "zòn?");
define('EDITOR_REVERT_PAGE_CONFIRM_1_MSG', "Èske ou sèten ou vle retounen a");
define('EDITOR_REVERT_PAGE_CONFIRM_2_MSG', "paj?");
define('EDITOR_REVERT_FILE_CONFIRM_1_MSG', "Èske ou sèten ou vle retounen a");
define('EDITOR_REVERT_FILE_CONFIRM_2_MSG', "ranpli?");
define('EDITOR_REVERT_HEAD_CONFIRM_1_MSG', "Èske ou sèten ou vle retounen a");
define('EDITOR_REVERT_HEAD_CONFIRM_2_MSG', "tèt?");
define('EDITOR_REVERT_CSS_CONFIRM_1_MSG', "Èske ou sèten ou vle retounen a");
define('EDITOR_REVERT_CSS_CONFIRM_2_MSG', "CSS?");
define('EDITOR_REVERTING_MSG', "Restore nan dènye pibliye vèsyon ...");
define('EDITOR_REVERT_COMPLETE_MSG', "retounen ranpli");
define('EDITOR_PAGE_NOT_SAVED_MSG', "paj ou a pa sove. ou vle pou konsève pou chanjman ou a?");
define('EDITOR_FILE_NOT_SAVED_MSG', "dosye ou a pa sove. ou vle pou konsève pou chanjman ou a?");
define('EDITOR_HEAD_NOT_SAVED_MSG', "tèt ou a pa sove. ou vle pou konsève pou chanjman ou a?");
define('EDITOR_CSS_NOT_SAVED_MSG', "CSS ou a pa sove. ou vle pou konsève pou chanjman ou a?");
define('EDITOR_PAGE_BLANK_ERR', "Page Non pa kapab vid. Tanpri antre nan yon non paj epi eseye ankò.");
define('EDITOR_FILE_BLANK_ERR', "File name pa kapab vid. Tanpri antre nan yon non dosye epi eseye ankò.");
define('EDITOR_FOLDER_BLANK_ERR', "Non Dosye pa ka vid. Tanpri antre nan yon non folder epi eseye ankò.");
define('EDITOR_HEAD_BLANK_ERR', "Head Non pa kapab vid. Tanpri antre nan yon non tèt epi eseye ankò.");
define('EDITOR_PAGE_ALREADY_EXISTS_1_ERR', "Page");
define('EDITOR_PAGE_ALREADY_EXISTS_2_ERR', "deja egziste. Tanpri, ale tounen nan meni prensipal la a kapab bay kopi ak chanje non paj ou yo.");
define('EDITOR_AREA_ALREADY_EXISTS_1_ERR', "zòn Border");
define('EDITOR_AREA_ALREADY_EXISTS_2_ERR', "deja egziste. Tanpri, ale tounen nan meni prensipal la nan jere zòn fwontyè.");
define('EDITOR_FILE_ALREADY_EXISTS_1_ERR', "file");
define('EDITOR_FILE_ALREADY_EXISTS_2_ERR', "deja egziste. Tanpri, ale tounen nan meni prensipal la a kapab bay kopi ak chanje non dosye ou.");
define('EDITOR_FOLDER_ALREADY_EXISTS_1_ERR', "dosye");
define('EDITOR_FOLDER_ALREADY_EXISTS_2_ERR', "deja egziste.");
define('EDITOR_ERROR_CREATING_FOLDER_ERR', "Erè: Pa t &#39;kapab kreye dosye.");
define('EDITOR_HEAD_ALREADY_EXISTS_1_ERR', "Head");
define('EDITOR_HEAD_ALREADY_EXISTS_2_ERR', "deja egziste. Tanpri, ale tounen nan meni prensipal la a kapab bay kopi ak chanje non tèt nou.");
define('EDITOR_DELETE_BLOG_CONFIRM_1_MSG', "Èske ou w ke ou vle efase <b>id blog</b>");
define('EDITOR_DELETE_BLOG_CONFIRM_2_MSG', "?");
define('EDITOR_DELETE_AREA_CONFIRM_1_MSG', "Èske ou sèten ou vle efase nan");
define('EDITOR_DELETE_AREA_CONFIRM_2_MSG', "zòn?");
define('EDITOR_DELETE_PAGE_CONFIRM_1_MSG', "Èske ou sèten ou vle efase nan");
define('EDITOR_DELETE_PAGE_CONFIRM_2_MSG', "paj?");
define('EDITOR_DELETE_FILE_CONFIRM_1_MSG', "Èske ou sèten ou vle efase nan");
define('EDITOR_DELETE_FILE_CONFIRM_2_MSG', "ranpli?");
define('EDITOR_DELETE_HEAD_CONFIRM_1_MSG', "Èske ou sèten ou vle efase nan");
define('EDITOR_DELETE_HEAD_CONFIRM_2_MSG', "tèt?");


///////////////////////// Create Page Select /////////////////////////
// Buttons:
define('CREATE_PAGE_SELECT_HEADING', "Kreye Page");
define('CREATE_PAGE_SELECT_ENTER_PAGE_NAME_BTN', "Antre nan Non Page");
define('CREATE_PAGE_SELECT_ADD_PLUGIN_BTN', "ajoute Plugin");
define('CREATE_PAGE_SELECT_SELECT_LAYOUT_BTN', "Chwazi Layout");
// Popup Messages:
define('CREATE_PAGE_SELECT_CREATING_A_PAGE', "Kreye yon Page");
define('CREATE_PAGE_SELECT_SELECTING_PAGE_LAYOUT', "Chwazi Layout Page");
define('CREATE_PAGE_SELECT_HELPFUL_TIPS', "Helpful Tips");

///////////////////////// Create Page Select /////////////////////////
// Console Text:
define('CREATE_PAGE_PAGE_NAME_BLANK_1_ERR', "Wouch! Ou bliye antre nan yon non paj.");
define('CREATE_PAGE_PAGE_NAME_BLANK_2_ERR', "ak antre nan yon non paj.");
define('CREATE_PAGE_PAGE_ALREADY_EXISTS_ERR', "a antre nan yon non paj diferan.");
define('CREATE_PAGE_DEFAULT_CONTENT', "Antre nan kontni ou isit la.");

///////////////////////// Manage Border Area Select /////////////////////////
// Buttons:
define('EDIT_BORDER_AREA_SELECT_HEADING', "Zòn Edit Border");
define('MANAGE_BORDER_AREA_HEADING', "Jere Zòn Border");
define('MANAGE_BORDER_AREA_BTN', "Jere Zòn Custom Border");

///////////////////////// Manage Border Areas /////////////////////////
// Buttons:
define('MANAGE_CUSTOM_BORDER_AREA_HEADING', "Jere Zòn Custom Border");
// Console Text:
define('MANAGE_CUSTOM_BORDER_AREA_ADD_AREA', "Ajoute Zòn Border");
define('MANAGE_CUSTOM_BORDER_AREA_ASSIGN_AREA', "Bay Zòn Border nan paj");
define('MANAGE_CUSTOM_BORDER_AREA_RENAME_AREA', "Chanje non Zòn Border");
define('MANAGE_CUSTOM_BORDER_AREA_DELETE_AREA', "Debarase m de Zòn Border");
define('MANAGE_CUSTOM_BORDER_AREA_RENAME_AREA_SELECT', "Chwazi zòn fwontyè chanje non");
define('MANAGE_CUSTOM_BORDER_AREA_NEW_NAME', "nouvo non");
define('MANAGE_CUSTOM_BORDER_AREA_DELETE_AREA_SELECT', "Chwazi zòn fwontyè yo efase");
// Popup Messages:
define('MANAGE_CUSTOM_BORDER_AREA_DELETE_AREA_CONFIRM_1_MSG', "Èske ou sèten ou vle efase nan");
define('MANAGE_CUSTOM_BORDER_AREA_DELETE_AREA_CONFIRM_2_MSG', "zòn?");
define('MANAGE_CUSTOM_BORDER_AREA_DELETED_1_MSG', "Zòn nan fwontyè");
define('MANAGE_CUSTOM_BORDER_AREA_DELETED_2_MSG', "te efase.");
define('MANAGE_CUSTOM_BORDER_AREA_DELETED_ERR', "Erè: Pa t &#39;kapab ajoute zòn fwontyè");
define('MANAGE_CUSTOM_BORDER_AREA_NOT_FOUND_1_ERR', "pa egziste.");
define('MANAGE_CUSTOM_BORDER_AREA_NOT_FOUND_2_ERR', "pou li retounen nan paj la plasman zòn nan.");
define('MANAGE_CUSTOM_BORDER_AREA_ASSIGNED_1_MSG', "Zòn ki fwontyè yo te re-asiyen nan la");
define('MANAGE_CUSTOM_BORDER_AREA_ASSIGNED_2_MSG', "paj.");
define('MANAGE_CUSTOM_BORDER_AREA_ASSIGNED_1_ERR', "Erè: Pa t &#39;kapab bay zòn fwontyè nan la");
define('MANAGE_CUSTOM_BORDER_AREA_ASSIGNED_2_ERR', "paj.");
define('MANAGE_CUSTOM_BORDER_AREA_NO_AREAS_FOUND_ERR', "Erè: zòn fwontyè Pa gen jwenn.");
define('MANAGE_CUSTOM_BORDER_AREA_ADDED_1_MSG', "Zòn nan fwontyè");
define('MANAGE_CUSTOM_BORDER_AREA_ADDED_2_MSG', "te te ajoute.");
define('MANAGE_CUSTOM_BORDER_AREA_ADDED_ERR', "Erè: Pa t &#39;kapab ajoute zòn fwontyè");
define('MANAGE_CUSTOM_BORDER_AREA_RENAMED_MSG', "te chanje non");
define('MANAGE_CUSTOM_BORDER_AREA_RENAMED_ERR', "Erè: Pa t &#39;kapab chanje non");
define('MANAGE_CUSTOM_BORDER_AREA_ALREADY_ASSIGNED_1_ERR', "Pa t &#39;kapab bay zòn fwontyè nan la");
define('MANAGE_CUSTOM_BORDER_AREA_ALREADY_ASSIGNED_3_ERR', "paj yo paske yo te deja asiyen.");

///////////////////////// Edit Blog Select /////////////////////////
// Buttons:
define('EDIT_BLOG_SELECT_CREATE_HEADING', "Kreye Blog nan paj");
define('EDIT_BLOG_SELECT_EDIT_HEADING', "Edit Post");

///////////////////////// Edit File Select /////////////////////////
// Buttons:
define('EDIT_FILE_SELECT_HEADING', "Edit File");
define('EDIT_FILE_SELECT_PAGE_FILES_BTN', "Edit Page Files");
define('EDIT_FILE_SELECT_INCLUDE_SCRIPTS_BTN', "Edit Enkli Scripts");
define('EDIT_FILE_SELECT_LIB_MODULES_BTN', "Edit Bibliyotèk Modil");
// Console Text:
define('EDIT_FILE_SELECT_SELECT_FILE', "Chwazi File");
// Popup Messages:
define('EDIT_FILE_SELECT_NO_FOLDER_ERR', "Erè: pa gen okenn katab espesifye");

///////////////////////// Edit Menu Items /////////////////////////
// Buttons:
define('EDIT_MENU_ITEMS_HEADING', "Edit Meni");
define('EDIT_MENU_ITEMS_UPDATE_ALL_BTN', "Mizajou tout");
// Console Text:
define('EDIT_MENU_ITEMS_SELECT_MENU', "Chwazi yon meni yo ajoute atik yo");
define('EDIT_MENU_ITEMS_ITEM_TEXT', "Item Tèks");
define('EDIT_MENU_ITEMS_NESTING_LEVEL', "nidifikasyon Nivo");
define('EDIT_MENU_ITEMS_URL', "URL");
define('EDIT_MENU_ITEMS_TARGET_WINDOW', "Sib Fenèt");
define('EDIT_MENU_ITEMS_TOP_LEVEL', "Top Nivo");
define('EDIT_MENU_ITEMS_1ST_SUB_LEVEL', "1st Nivo Gwoup");
define('EDIT_MENU_ITEMS_2ND_SUB_LEVEL', "2nd Nivo Gwoup");
define('EDIT_MENU_ITEMS_3RD_SUB_LEVEL', "3yèm Nivo Gwoup");
define('EDIT_MENU_ITEMS_4TH_SUB_LEVEL', "4yèm Nivo Gwoup");
define('EDIT_MENU_ITEMS_5TH_SUB_LEVEL', "5yèm Nivo Gwoup");
define('EDIT_MENU_ITEMS_SELECT_MENU_MSG', "Tanpri chwazi yon meni edite atik meni.");
// Popup Messages:
define('EDIT_MENU_ITEMS_DELETE_ITEM_CONFIRM_1_MSG', "Èske ou sèten ou vle efase nan");
define('EDIT_MENU_ITEMS_DELETE_ITEM_CONFIRM_2_MSG', "atik meni?");
define('EDIT_MENU_ITEMS_STARTING_DELETE_MSG', "Koumanse efase ...");
define('EDIT_MENU_ITEMS_LOCATING_MENU_ITEMS_MSG', "Lokalize bagay ki nan meni ...");
define('EDIT_MENU_ITEMS_COULD_NOT_DELETE_ITEM_MSG', "Pa gen dosye yo te jwenn. Pa t &#39;kapab efase atik meni.");
define('EDIT_MENU_ITEMS_MENU_ITEM_DELETED_MSG', "atik meni efase");
define('EDIT_MENU_ITEMS_DELETING_MENU_ITEM_MSG', "Efase atik meni ...");
define('EDIT_MENU_ITEMS_COULD_NOT_UPDATE_ITEM_MSG', "Pa gen dosye yo te jwenn. Pa t &#39;kapab mete ajou atik meni.");
define('EDIT_MENU_ITEMS_MENU_ITEM_UPDATED_MSG', "atik meni mete ajou");
define('EDIT_MENU_ITEMS_UPDATING_MENU_ITEM_MSG', "Mete ajou atik meni ...");
define('EDIT_MENU_ITEMS_COULD_NOT_UPDATE_ITEMS_MSG', "Pa gen dosye yo te jwenn. Pa t &#39;kapab mete ajou bagay ki nan meni.");
define('EDIT_MENU_ITEMS_MENU_ITEMS_UPDATED_MSG', "bagay ki nan meni mete ajou");
define('EDIT_MENU_ITEMS_UPDATING_MENU_ITEMS_MSG', "Mete ajou bagay ki nan meni ...");
define('EDIT_MENU_ITEMS_RETRIEVING_MENU_ITEMS_MSG', "Retwouve bagay ki nan meni ...");
define('EDIT_MENU_ITEMS_NOT_SAVED_CONFIRM_MSG', "chanjman ou a pa yo te sove. ou vle sove chanjman ou anvan yo tounen nan meni prensipal la?");

///////////////////////// Manage Menu Assignments /////////////////////////
// Buttons:
define('MANAGE_MENUS_HEADING', "Jere Devwa Menu");
define('MANAGE_MENUS_CREATE_NEW_MENU_BTN', "Kreye nouvo Menu");
// Console Text:
define('MANAGE_MENUS_ADD_MENU', "ajoute Menu");
define('MANAGE_MENUS_MENU_TYPE', "Kalite Menu");
define('MANAGE_MENUS_ASSIGN_MENU_TO_BORDER', "Bay Menu nan zòn Border");
define('MANAGE_MENUS_DELETE_MENU', "Debarase m de Menu");
define('MANAGE_MENUS_SELECT_MENU_TO_DELETE', "Chwazi meni an ou vle efase");
define('MANAGE_MENUS_UPDATE_MENU_DESCRIPTION', "Mizajou Menu Deskripsyon");
define('MANAGE_MENUS_SELECT_MENU_TO_REVISE', "Chwazi meni an ou vle revize");
define('MANAGE_MENUS_NEW_DESCRIPTION', "nouvo Deskripsyon");
// Popup Messages:
define('MANAGE_MENUS_REASSIGN_MENU_TO_COMPLETE_MSG', "Ou ap bezwen re-bay meni sa a nan zòn nan fwontyè ranpli konvèsyon an.");
define('MANAGE_MENUS_DELETE_MENU_CONFIRM_1_MSG', "Èske ou sèten ou vle efase nan");
define('MANAGE_MENUS_DELETE_MENU_CONFIRM_2_MSG', "meni?");
define('MANAGE_MENUS_MENU_ASSIGNED_1_MSG', "nan");
define('MANAGE_MENUS_MENU_ASSIGNED_2_MSG', "meni");
define('MANAGE_MENUS_MENU_ASSIGNED_3_MSG', "te asiyen nan la");
define('MANAGE_MENUS_MENU_ASSIGNED_4_MSG', "zòn fwontyè.");

///////////////////////// Edit CSS Menu Parameters /////////////////////////
// Buttons:
define('EDIT_CSS_MENU_PARAMETERS_HEADING', "CSS Menu paramèt Editè Quick-Enstalasyon");
// Console Text:
define('EDIT_CSS_MENU_PARAMETERS_SELECT_MENU', "Chwazi yon meni nan konfigirasyon");
define('EDIT_CSS_MENU_PARAMETERS_LAYOUT_ORIGIN', "Menu Layout ak Orijin (ki soti nan siperyè agòch nan paj la)");
define('EDIT_CSS_MENU_PARAMETERS_LOCATION', "Menu Kote");
define('EDIT_CSS_MENU_PARAMETERS_FIXED_WIDTH', "(Fiks lajè)");
define('EDIT_CSS_MENU_PARAMETERS_VARIABLE_WIDTH', "(Varyab lajè)");
define('EDIT_CSS_MENU_PARAMETERS_MENU_WIDTH', "Lajè Menu");
define('EDIT_CSS_MENU_PARAMETERS_SPECIAL_NOTE', "Remak: Chwazi nenpòt nan kote ki anwo yo pa bay meni nan youn nan zòn sa yo. Li senpleman mete aksan sou fòm sa a ak anviwònman yo tipik pou zòn nan chwazi.");
define('EDIT_CSS_MENU_PARAMETERS_ITEM_SIZE_PADDING', "Menu Item gwosè ak ranbouraj");
define('EDIT_CSS_MENU_PARAMETERS_SUB_MENU_POSITIONING', "Gwoup Pozisyon Menu");
define('EDIT_CSS_MENU_PARAMETERS_OFFSET_FROM_TOP', "Offset soti nan Top");
define('EDIT_CSS_MENU_PARAMETERS_OFFSET_FROM_LEFT', "Offset soti nan Left");
define('EDIT_CSS_MENU_PARAMETERS_COLLAPSE_EXPAND', "Tonbe plat atè ak Elaji");
define('EDIT_CSS_MENU_PARAMETERS_SUB_MENU_SIZE_PADDING', "Sub atik meni gwosè ak ranbouraj");
define('EDIT_CSS_MENU_PARAMETERS_SELECT_MENU_MSG', "Tanpri chwazi yon meni nan konfigirasyon.");

///////////////////////// Edit CSS Menu Styles /////////////////////////
// Buttons:
define('EDIT_CSS_MENU_STYLES_HEADING', "Styles CSS Menu Quick-Enstalasyon Editè");
// Console Text:
define('EDIT_CSS_MENU_STYLES_SELECT_MENU', "Chwazi yon meni yo style");
define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_FONT', "Top Nivo Font");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_FONT', "Gwoup Nivo 1 Font");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_FONT', "Gwoup Nivo 2 Font");
define('EDIT_CSS_MENU_STYLES_COLORS_BACKGROUND', "Koulè ak Jan nou koumanse");
define('EDIT_CSS_MENU_STYLES_NORMAL_MOUSE_OUT', "Nòmal (soti sourit)");
define('EDIT_CSS_MENU_STYLES_HOVER_MOUSE_OVER', "Hover (sourit lòt bò a)");
define('EDIT_CSS_MENU_STYLES_ACTIVE_MOUSE_CLICK', "Aktif (klike sou sourit)");
define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_TEXT_COLOR', "Top Nivo Tèks Koulè");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_TEXT_COLOR', "Gwoup Nivo 1 Tèks Koulè");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_TEXT_COLOR', "Gwoup Nivo 2 Tèks Koulè");
define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_BACKGROUND_COLOR', "Top Nivo Jan nou koumanse Koulè");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_BACKGROUND_COLOR', "Gwoup Nivo Jan nou koumanse Koulè");
define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_BLOCK_BORDER_COLOR', "Top Nivo blòk Border Koulè");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_BLOCK_BORDER_COLOR', "Gwoup Nivo blòk Border Koulè");
define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_ITEM_BORDER_COLOR', "Top Nivo Item Border Koulè");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_ITEM_BORDER_COLOR', "Gwoup Nivo Item Border Koulè");
define('EDIT_CSS_MENU_STYLES_TOP_BORDER_VERTICAL', "T <br> o <br> p");
define('EDIT_CSS_MENU_STYLES_BOTTOM_BORDER_VERTICAL', "B <br> o <br> t <br> t <br> o <br> m");
define('EDIT_CSS_MENU_STYLES_LEFT_BORDER_VERTICAL', "L <br> e <br> f <br> t");
define('EDIT_CSS_MENU_STYLES_RIGHT_BORDER_VERTICAL', "R <br> mwen <br> g <br> h <br> t");
define('EDIT_CSS_MENU_STYLES_UNDERLINE_NOTE', "pral Link-soulinye dwe fòse yo koupe sof si soulinye se tcheke");
define('EDIT_CSS_MENU_STYLES_SAME_AS_TOP_LEVEL_NOTE', "(Menm ak nivo tèt)");
define('EDIT_CSS_MENU_STYLES_SAME_AS_NORMAL_NOTE', "(Menm ak nòmal)");
define('EDIT_CSS_MENU_STYLES_SELECT_MENU_MSG', "Tanpri chwazi yon meni nan style.");
// Popup Messages:
define('EDIT_CSS_MENU_STYLES_LETTER_SPACING_MSG', "Ou te chwazi <b>Nòmal,</b> <b>Inisyal</b> oswa <b>eritye</b> pou espas lèt ou a, men ou gen yon nimewo fikse pou lèt espas. Remake byen ke yo pral nimewo a ou te chwazi dwe inyore. Si ou vle mete yon espas lèt, chwazi <b>px</b> pito.");
define('EDIT_CSS_MENU_STYLES_SAVE_SUCCESS_MSG', "Styles meni ou yo te sove.");
define('EDIT_CSS_MENU_STYLES_SAVE_FAIL_ERR', "Te gen yon erè ekonomize estil meni ou.");

///////////////////////// Edit JS Menu Parameters /////////////////////////
// Buttons:
define('EDIT_JS_MENU_PARAMETERS_HEADING', "JavaScript Kantite moun ki Menu ak Oryantasyon Editè");
// Console Text:
define('EDIT_JS_MENU_PARAMETERS_SELECT_MENU', "Chwazi yon meni nan konfigirasyon");
define('EDIT_JS_MENU_PARAMETERS_MENU_ITEM_SIZE', "Atik meni Kantite moun ki");
define('EDIT_JS_MENU_PARAMETERS_MENU_ORIGIN', "Orijin Menu (ki soti nan siperyè agòch nan paj la)");
define('EDIT_JS_MENU_PARAMETERS_SUB_MENU_ORIGIN', "Sub Orijin Menu (ki soti nan siperyè agòch nan Main Menu)");
define('EDIT_JS_MENU_PARAMETERS_MENU_ITEM_OFFSET', "Atik meni Offset");
define('EDIT_JS_MENU_PARAMETERS_SUB_MENU_ITEM_OFFSET_SIZE', "Sub atik meni Offset ak Kantite moun ki");
define('EDIT_JS_MENU_PARAMETERS_PROPORTIONAL_SIZING', "pwopòsyonèl Dimensionnement");
define('EDIT_JS_MENU_PARAMETERS_SUB_MENU_WIDTH', "Sub Menu Item Lajè");
define('EDIT_JS_MENU_PARAMETERS_SUB_MENU_HEIGHT', "Sub Menu Item Tay");
define('EDIT_JS_MENU_PARAMETERS_OFFSET_FROM_LEFT_OF_TOP_MENU', "Offset soti nan Left nan Top Menu");
define('EDIT_JS_MENU_PARAMETERS_HIDE_DELAY_ON_MOUSE_OUT', "Kache reta apre Mouse soti (m)");
define('EDIT_JS_MENU_PARAMETERS_VERTICAL_HORIZONTAL_MENU_NOTE', "Remak: pou mete meni vètikal Offset de gòch a 0. Pou seri meni orizontal Offset depi anwo jouk 0.");
define('EDIT_JS_MENU_PARAMETERS_SELECT_MENU_MSG', "Tanpri chwazi yon meni nan konfigirasyon.");
// Popup Messages:
define('EDIT_JS_MENU_PARAMETERS_SAVE_SUCCESS_MSG', "paramèt meni ou yo te sove.");
define('EDIT_JS_MENU_PARAMETERS_SAVE_FAIL_ERR', "Te gen yon erè ekonomize paramèt meni ou.");

///////////////////////// Edit JS Menu Styles /////////////////////////
// Buttons:
define('EDIT_JS_MENU_STYLES_HEADING', "JavaScript Styles Menu Editè");
// Console Text:
define('EDIT_JS_MENU_STYLES_SELECT_MENU', "Chwazi yon meni yo style");
define('EDIT_JS_MENU_STYLES_TOP_MENU_MENU', "Top-Level Menu");
define('EDIT_JS_MENU_STYLES_SUB_LEVEL_1_MENU', "Sub-Nivo 1 Menu");
define('EDIT_JS_MENU_STYLES_SUB_LEVEL_2_MENU', "Sub-Nivo 2 Menu");
define('EDIT_JS_MENU_STYLES_PADDING', "Ranbouraj (tèt dwat bò gòch anba)");
define('EDIT_JS_MENU_STYLES_SELECT_MENU_MSG', "Tanpri chwazi yon meni nan style.");

///////////////////////// Edit CSS Select /////////////////////////
// Buttons:
define('EDIT_CSS_SELECT_HEADING', "Styles Edit");
define('EDIT_CSS_SELECT_COPY_STYLES_TO_MOBILE_BTN', "Kopi Style Fèy mobil");
define('COPY_STYLE_TO_MOBILE_NOTE', "fonksyon sa a se pou inisyalizin estil yo mobil ak estil yo Desktop analoji yon fwa ou fin fè mete kanpe dra style ou pou wè Desktop. L &#39;a sa a fonksyon pral recouvrir nenpòt estil ou te kreye pou fèy la style mobil w ap kopye nan. Li pa nesesè yo sèvi ak fonksyon sa a, men li kapab sou la men kòm yon pwen depa pou kreye estil mobil ou. Epitou, ou ka kreye dra style mobil pou dra style ki pa gen analoji dra style mobil pa defo.");
define('COPY_STYLE_TO_MOBILE_CONFIRM_1_MSG', "Èske ou sèten ou vle kopi");
define('COPY_STYLE_TO_MOBILE_CONFIRM_2_MSG', "? Tout moun nan estil yo nan");
define('COPY_STYLE_TO_MOBILE_CONFIRM_3_MSG', "yo pral écrase. (Sa a pa ka undone.)");
define('COPY_STYLE_TO_MOBILE_COMPLETE_MSG', "te kopye nan");
define('COPY_STYLE_TO_MOBILE_COMPLETE_ERR', "Te gen yon kopye erè");
// Popup Messages:
define('EDIT_CSS_SELECT_MENU_WARNING', "AVÈTISMAN SOU: Korije meni CSS dirèkteman kapab lakòz rezilta enprevwayab. manier Menu yo ta dwe fè lè l sèvi avèk editè yo style meni. ta dwe meni Korije CSS nan editè a CSS sèlman dwe fè pa devlopè entènèt ekspè.");
define('EDIT_CSS_SELECT_MENU_ITEM_WARNING', "AVI: Lè manier bagay ki nan meni endividyèl, jeu &#39;Display&#39; nan &#39;Lis Item&#39; yo sa aktive yo nan navigatè entènèt.");

///////////////////////// Edit CSS /////////////////////////
// Buttons:
define('EDIT_CSS_HEADING', "Styles Edit");
define('EDIT_CSS_ADD_DELETE_CUSTOM_STYLE_BTN', "Add / efase Custom Style");
define('EDIT_CSS_LOAD_BROWSER_RESET_CSS_BTN', "Chaj navigatè Reyajiste CSS");
define('EDIT_CSS_SETUP_CENTERED_PAGES_BTN', "Enstalasyon Pou santre Paj");
define('EDIT_CSS_SETUP_STICKY_FOOTER_BTN', "Enstalasyon Pou Sticky Footer");
// Console Text:
define('EDIT_CSS_CHANGE_STYLE_SHEET', "Chanje style Fèy");
define('EDIT_CSS_USE_SETTINGS_BELOW', "Sèvi ak Anviwònman Pi ba a");
define('EDIT_CSS_GO_TO', "Ale nan");
define('EDIT_CSS_SORT_ALPHABETICALLY', "Sòt par");
define('EDIT_CSS_CLICK_NONE_MSG', "Klike sou &#39;Okenn&#39; sèlman nan klèman aplike pa gen okenn decoration tèks.");
define('EDIT_CSS_WHITE_SPACE', "Blan Espas");
define('EDIT_CSS_TABLE_LAYOUT', "Layout Table");
define('EDIT_CSS_CURSOR', "Kurseur");
define('EDIT_CSS_OUTLINE_STYLE', "Plan Style");
define('EDIT_CSS_BORDER_COLLAPSE', "Border Haiti");
define('EDIT_CSS_TOP_LEFT', "Top Left");
define('EDIT_CSS_TOP_RIGHT', "Top Dwa");
define('EDIT_CSS_BOTTOM_RIGHT', "anba Dwa");
define('EDIT_CSS_BOTTOM_LEFT', "anba Left");
define('EDIT_CSS_Z_INDEX', "Z Index");
define('EDIT_CSS_BACKGROUND_IMAGE', "Jan nou koumanse Imaj");
define('EDIT_CSS_CLICK_AUTO_MSG', "Klike sou &#39;Auto&#39; sèlman nan klèman aplike Marge oto.");
define('EDIT_CSS_REPEAT_HORIZONTALLY', "repete Orizontal");
define('EDIT_CSS_REPEAT_VERTICALLY', "repete Vètikal");
define('EDIT_CSS_NO_REPEAT', "Pa gen Repete");
define('EDIT_CSS_INLINE_BLOCK', "Inline-blòk");
define('EDIT_CSS_LIST_ITEM', "Lis atik");
define('EDIT_CSS_RUN_IN', "Run Nan");
define('EDIT_CSS_INLINE_TABLE', "inline Table");
define('EDIT_CSS_TABLE_ROW_GROUP', "Table Ranje Gwoup");
define('EDIT_CSS_TABLE_FOOTER_GROUP', "Table Footer Gwoup");
define('EDIT_CSS_TABLE_ROW', "Table Ranje Gwoup");
define('EDIT_CSS_TABLE_COLUMN_GROUP', "Table Kolòn Gwoup");
define('EDIT_CSS_TABLE_COLUMN', "Table Kolòn Gwoup");
define('EDIT_CSS_TABLE_CELL', "Table Pòtab");
define('EDIT_CSS_TABLE_CAPTION', "Table Caption");
define('EDIT_CSS_ALL_SCROLL', "tout Scroll");
define('EDIT_CSS_CONTEXT_MENU', "Context Menu");
define('EDIT_CSS_COLUMN_RESIZE', "kolòn Rdimansyonman");
define('EDIT_CSS_ROW_RESIZE', "Ranje Rdimansyonman");
define('EDIT_CSS_NO_DROP', "Pa gen-Drop");
define('EDIT_CSS_NOT_ALLOWED', "pa Nou pèmèt yo");
define('EDIT_CSS_VERTICAL_TEXT', "vètikal Tèks");
define('EDIT_CSS_EAST_RESIZE', "East-Rdimansyonman");
define('EDIT_CSS_EAST_WEST_RESIZE', "East-West Rdimansyonman");
define('EDIT_CSS_NORTH_RESIZE', "Nò Rdimansyonman");
define('EDIT_CSS_NORTH_EAST_RESIZE', "Nò-Lès Rdimansyonman");
define('EDIT_CSS_NORTH_EAST_SOUTH_WEST_RESIZE', "Nò-East-sid-West Rdimansyonman");
define('EDIT_CSS_NORTH_SOUTH_RESIZE', "Nò-Sid Rdimansyonman");
define('EDIT_CSS_NORTH_WEST_RESIZE', "North-West Rdimansyonman");
define('EDIT_CSS_NORTH_WEST_SOUTH_EAST_RESIZE', "North-West-Sid-Lès Rdimansyonman");
define('EDIT_CSS_SOUTH_RESIZE', "South Rdimansyonman");
define('EDIT_CSS_SOUTH_EAST_RESIZE', "Sid-Lès Rdimansyonman");
define('EDIT_CSS_SOUTH_WEST_RESIZE', "Sid-West Rdimansyonman");
define('EDIT_CSS_WEST_RESIZE', "West Rdimansyonman");
define('EDIT_CSS_ZOOM_IN', "Zoom In");
define('EDIT_CSS_ZOOM_OUT', "rale soti");
define('EDIT_CSS_TOP_CENTER', "Top Sant");
define('EDIT_CSS_CENTER_LEFT', "sant Left");
define('EDIT_CSS_CENTER_CENTER', "sant sant");
define('EDIT_CSS_CENTER_RIGHT', "sant Dwa");
define('EDIT_CSS_BOTTOM_CENTER', "anba Sant");
define('EDIT_CSS_XPOS_YPOS', "Xpos Ypos");
define('EDIT_CSS_DECIMAL_LEADING_ZERO', "Desimal dirijan Zewo");
define('EDIT_CSS_LOWER_ROMAN', "Lower Women");
define('EDIT_CSS_UPPER_ROMAN', "Upper Women");
define('EDIT_CSS_LOWER_ALPHA', "Lower Alpha");
define('EDIT_CSS_UPPER_ALPHA', "Upper Alpha");
define('EDIT_CSS_LOWER_GREEK', "Lower Greek");
define('EDIT_CSS_LOWER_LATIN', "Lower Latin");
define('EDIT_CSS_UPPER_LATIN', "Upper Latin");
define('EDIT_CSS_CJK_IDEOGRAPHIC', "Kchk-ideografik");
define('EDIT_CSS_HIRAGANA', "Hiragana");
define('EDIT_CSS_KATAKANA', "katakana");
define('EDIT_CSS_HIRAGANA_IROHA', "Hiragana Iroha");
define('EDIT_CSS_KATAKANA_IROHA', "katakana Iroha");
// Popup Messages:
define('EDIT_CSS_CLICK_UPDATE_TO_COMMIT_MSG', "Klike sou &#39;Mizajou&#39; la peche chanjman.");
define('EDIT_CSS_UPDATE_COMPLETE_MSG', "Mizajou konplè");
define('EDIT_CSS_UPDATE_READY_TO_SEND_MSG', "Mete ajou pare yo voye ...");
define('EDIT_CSS_UPDATE_SENT_MSG', "Mizajou voye");
define('EDIT_CSS_UPDATING_MSG', "Mete ajou ...");
define('EDIT_CSS_RESET_BROWSER_CSS_COMPLETE_MSG', "te CSS ou te konfigirasyon Reyajiste navigatè pa mete tout nan marges, ranbouraj yo ak sou fwontyè pou eleman nan HTML a 0, ak tout nan marges yo pou eleman nan kò a 0.");
define('EDIT_CSS_LOAD_CENTERED_PAGES_CSS_ALERT_MSG', "Nou pral kounye a chaje estil ak anviwònman ki pral lakòz sit entènèt ou a parèt santre ak yon lajè fiks yo.");
define('EDIT_CSS_LOAD_CENTERED_PAGES_CSS_COMPLETE_MSG', "gen sou sit ou te santre. Ou ka vle revize &#39;kò&#39; lajè a, &#39;kò&#39; koulè a ​​background, ak &#39;#wrap&#39; koulè a ​​backgound a bezwen ou yo.");
define('EDIT_CSS_LOAD_STICKY_FOOTERS_ALERT_MSG', "Nou pral kounye a chaje estil ak anviwònman ki pral lakòz footer a nan paj entènèt ou a &#39;baton&#39; nan fon an nan fenèt navigatè ou a.");
define('EDIT_CSS_LOAD_STICKY_FOOTERS_COMPLETE_MSG', "footer ou pral kounye a bwa nan pati anba a nan fenèt navigatè a. Ou kapab vle tou revize wotè a &#39;footer&#39; ak koulè nan background nan bezwen ou yo. Asire ou ke ou mete tèt Marge footer a nan menm bagay la tou men negatif nan wotè footer a.");
define('EDIT_CSS_BORDER_REQUIREMENTS_MSG', "Li parèt ke ou yo ap eseye konfigirasyon yon fwontyè, men ou pa gen okenn kote chwazi. Ou dwe tcheke omwen youn nan bwat yo ki make <b>Top,</b> <b>anba,</b> <b>Left</b> oswa <b>Dwa.</b>");
define('EDIT_CSS_BORDER_REQUIREMENTS_STYLE_ADENDUM_MSG', "Ou dwe presize yon <b>stil fwontyè</b> nan lòd pou yon fwontyè yo montre.");
define('EDIT_CSS_LETTER_SPACING_REQUIREMENTS_MSG', "Ou te chwazi <b>Nòmal,</b> <b>Inisyal</b> oswa <b>eritye</b> pou espas lèt ou a, men ou gen yon nimewo fikse pou lèt espas. Remake byen ke yo pral nimewo a ou te chwazi dwe inyore. Si ou vle mete yon espas lèt, chwazi <b>px</b> pito.");
define('EDIT_CSS_LINE_HEIGHT_REQUIREMENTS_MSG', "Ou te chwazi <b>Nòmal</b> oswa <b>eritye</b> pou wotè liy ou, men ou gen yon nimewo pozitif fikse pou wotè liy. Remake byen ke yo pral nimewo a ou te chwazi dwe inyore. Si ou vle mete yon wotè liy, chwazi <b><b>Bultiplyer,%</b></b> oswa <b>px</b> pito.");
define('EDIT_CSS_SORTING_CLASS_LIST_MSG', "Fouye lis klas ...");
define('EDIT_CSS_SORT_COMPLETE', "Sòt konplè");
define('EDIT_CSS_SORTING_MSG', "Fouye ...");
define('EDIT_CSS_COULD_NOT_RENAME_1_ERR', "Pa t &#39;kapab chanje non");
define('EDIT_CSS_COULD_NOT_RENAME_2_ERR', "");
define('EDIT_CSS_CANT_CREATE_ERR', "Pa ka kreye");
define('EDIT_CSS_SELECT_PAGE_FOR_PREVIEW', "Chwazi yon paj nan preview chanjman CSS ou");

///////////////////////// Edit CLASSES /////////////////////////
// Buttons:
define('CLASSES_HEADING', "Add / efase Custom Style");
define('CLASSES_BACK_TO_EDIT_CSS', "Retounen nan Edit Sit CSS");
// Console Text:
define('CLASSES_ADD_CLASS', "ajoute Gwoup");
define('CLASSES_CREATE_SUB_CLASS', "Kreye Gwoup / Souklas relasyon");
define('CLASSES_DELETE_CLASS', "Debarase m de Gwoup");
define('CLASSES_EDIT_CLASS_DESCRIPTION', "Edit Gwoup Deskripsyon");
define('CLASSES_SET_CLASS_SORT_ORDER', "Mete Gwoup Sòt Lòd");
define('CLASSES_CREATE_LINK_SET', "Kreye Link Mete");
define('CLASSES_CLASS_DESCRIPTION', "Gwoup / Deskripsyon");
define('CLASSES_CLASS_ID_NOTE', "Chwazi &#39;Gwoup&#39; pou. (Dot) prefiks oswa chwazi &#39;ID&#39; pou # prefiks.");
define('CLASSES_COPY_CLASS', "Kopi / Chanje non Gwoup");
define('CLASSES_FROM_CLASS', "Soti nan Gwoup");
define('CLASSES_TO_CLASS', "plas Gwoup");
define('CLASSES_TO_STYLE_SHEET', "Nan style Fèy");
define('CLASSES_NO_CUSTOM_CLASSES_DEFINED', "klas koutim -Pa gen denfined-");
// Popup Messages:
define('CLASSES_DELETE_CLASS_CONFIRM_1_MSG', "Èske ou sèten ou vle efase klas la");
define('CLASSES_DELETE_CLASS_CONFIRM_2_MSG', "?");
define('CLASSES_DESCRIPTION_NOT_FOUND_MSG', "Pa gen dosye yo te jwenn. Pa t &#39;kapab jwenn deskripsyon.");
define('CLASSES_DESCRIPTION_FOUND_MSG', "Deskripsyon Twouve");
define('CLASSES_COULD_NOT_UPDATE_DESCRIPTION_MSG', "Pa gen dosye yo te jwenn. Pa t &#39;kapab mete ajou deskripsyon.");
define('CLASSES_DESCRIPTION_UPDATED_MSG', "Deskripsyon mete ajou");
define('CLASSES_STARTING_POPULATE_MSG', "Koumanse peple ...");
define('CLASSES_COPY_FROM_CLASS_BLANK_ERR', "Tanpri chwazi yon klas a kapab bay kopi nan.");
define('CLASSES_COPY_TO_CLASS_BLANK_ERR', "Tanpri antre yon klas a kapab bay kopi a.");
define('CLASSES_COPY_CLASS_COMPLETE_MSG', "kopi Gwoup konplè!");
define('CLASSES_COPY_CLASS_ERR', "Yon erè te fèt ap eseye kopi klas la.");
define('CLASSES_COPY_CLASS_TO_CLASS_ALREADY_EXISTS_ERR', "ERÈ: Klas la ou yo ap eseye kopi nan deja egziste.");
define('CLASSES_UPDATE_SORT_ORDER_COMPLETE_MSG', "Lòd yo sòt yo te mete ajou.");
define('CLASSES_UPDATE_SORT_ORDER_UPDATE_ERR', "ERÈ: Te gen yon erè à lòd yo sòt.");
define('CLASSES_ADD_CLASS_COMPLETE_MSG', "gen klas nouvèl nou te ajoute.");
define('CLASSES_ADD_CLASS_ADD_ERR', "deja egziste nan baz done.");
define('CLASSES_DEFINE_SUBCLASS_COMPLETE_MSG', "te nouvo souklas ou te kreye.");
define('CLASSES_DEFINE_SUBCLASS_DEFINE_ERR', "ERÈ: Te gen yon erè kreye nouvo souklas ou yo.");
define('CLASSES_DELETE_CLASS_COMPLETE_MSG', "Gwoup efase avèk siksè.");
define('CLASSES_ADD_CLASS_CANNOT_BE_BLANK_MSG', "Non Gwoup / ID pa kapab vid. Tanpri ranpli nan yon klas oswa ID non.");

///////////////////////// Edit Head Select /////////////////////////
// Buttons:
define('EDIT_HEAD_SELECT_HEADING', "Edit Head Kòd");

///////////////////////// Manage Head /////////////////////////
// Buttons:
define('MANAGE_HEAD_HEADING', "Jere tèt Kòd");
define('MANAGE_HEAD_ADD_HEAD_BTN', "Ajoute Yon lòt avantou Head");
// Console Text:
define('MANAGE_HEAD_ADD_HEAD_CONTENT', "Ajoute Head avantou");
define('MANAGE_HEAD_ASSIGN_HEAD_CONTENT_TO_PAGE', "Bay tèt avantou nan paj");
define('MANAGE_HEAD_RENAME_HEAD_CONTENT', "Chanje non Head avantou");
define('MANAGE_HEAD_DELETE_HEAD_CONTENT', "Debarase m de tèt avantou");
define('MANAGE_HEAD_SELECT_HEAD_CONTENT_TO_RENAME', "Chwazi kontni tèt chanje non");
define('MANAGE_HEAD_SELECT_HEAD_CONTENT_TO_DELETE', "Chwazi kontni tèt yo efase");
define('MANAGE_HEAD_NEW_NAME', "nouvo non");
// Popup Messages:
define('MANAGE_HEAD_DELETE_HEAD_CONFIRM_1_MSG', "Èske ou sèten ou vle efase nan");
define('MANAGE_HEAD_DELETE_HEAD_CONFIRM_2_MSG', "tèt?");
define('MANAGE_HEAD_DELETED_1_MSG', "tèt la");
define('MANAGE_HEAD_DELETED_2_MSG', "te efase.");
define('MANAGE_HEAD_DELETED_ERR', "Erè: Pa t &#39;kapab ajoute tèt");
define('MANAGE_HEAD_NO_HEADS_FOUND_ERR', "Erè: Non tèt jwenn.");
define('MANAGE_HEAD_NOT_FOUND_1_ERR', "pa egziste.");
define('MANAGE_HEAD_NOT_FOUND_2_ERR', "pou li retounen nan paj la tèt plasman.");
define('MANAGE_HEAD_ASSIGNED_1_MSG', "ki te re-asiyen nan la");
define('MANAGE_HEAD_ASSIGNED_2_MSG', "paj.");
define('MANAGE_HEAD_ASSIGNED_1_ERR', "Erè: Pa t &#39;kapab bay");
define('MANAGE_HEAD_ASSIGNED_2_ERR', "nan la");
define('MANAGE_HEAD_ASSIGNED_3_ERR', "paj.");
define('MANAGE_HEAD_ADDED_1_MSG', "tèt la");
define('MANAGE_HEAD_ADDED_2_MSG', "te te ajoute.");
define('MANAGE_HEAD_ADDED_ERR', "Erè: Pa t &#39;kapab ajoute tèt");
define('MANAGE_HEAD_PAGE_ALREADY_EXISTS_1_ERR', "tèt la");
define('MANAGE_HEAD_PAGE_ALREADY_EXISTS_2_ERR', "deja egziste. Tanpri antre nan yon non tèt diferan.");
define('MANAGE_HEAD_ALREADY_ASSIGNED_1_ERR', "Pa t &#39;kapab bay");
define('MANAGE_HEAD_ALREADY_ASSIGNED_3_ERR', "paj paske li se deja asiyen.");

///////////////////////// Edit Favicon /////////////////////////
// Buttons:
define('EDIT_FAVICON_HEADING', "Edit favikon");
define('EDIT_FAVICON_UPLOAD_BTN', "Voye");
// Console Text:
define('EDIT_FAVICON_UPLOAD_FAVICON', "Voye favikon");
// Popup Messages:
define('EDIT_FAVICON_DELETE_FAVICON_CONFIRM', "Èske ou w ke ou vle efase favikon a?");
define('EDIT_FAVICON_UPLOAD_SUCCESS_MSG', "te favikon te Uploaded.");
define('EDIT_FAVICON_ONLY_ICONS_ALLOWED_MSG', "Se sèlman icon dosye yo gen dwa yo dwe Uploaded, sa vle di &#39;myicon.ico&#39;. tanpri klike");
define('EDIT_FAVICON_UPLOAD_FAIL_ERR', "Te gen yon erè uploading dosye a.");

///////////////////////// Edit Page Titles /////////////////////////
// Buttons:
define('EDIT_PAGE_TITLES_HEADING', "Edit Page Tit");
// Console Text:
define('EDIT_PAGE_TITLES_REVISE_DEFAULT_PAGE_TITLE', "Revize Default Page Tit");
define('EDIT_PAGE_TITLES_SELECT_PAGE', "Chwazi yon paj chanje tit la nan");
define('EDIT_PAGE_TITLES_REVISE_SITE_TITLE', "Revize sit Tit");
define('EDIT_PAGE_TITLES_SITE_TITLE_NOTE', "fen liv nan tit paj si egziste");
// Popup Messages:
define('EDIT_PAGE_TITLES_PAGE_TILE_SAVED_MSG', "yo Paj tit te sove.");

///////////////////////// Edit Meta Tags /////////////////////////
// Buttons:
define('EDIT_META_TAGS_HEADING', "Edit Meta Tags");
// Console Text:
define('EDIT_META_TAGS_SELECT_PAGE', "Chwazi yon paj");
define('EDIT_META_TAGS_KEYWORDS_NOTE', "Remak: Sèvi ak vigil &quot;,&quot; separe mo kle ak fraz kle.");
// Popup Messages:
define('EDIT_META_TAGS_META_TAGS_SAVED_MSG', "Tags Meta yo te sove.");

///////////////////////// Delete Page or Blog /////////////////////////
// Buttons:
define('DELETE_PAGE_OR_BLOG_HEADING', "Debarase m de Page oswa Blog");
// Console Text:
define('DELETE_PAGE_OR_BLOG_SELECT_PAGE', "Chwazi paj la ou vle efase");
define('DELETE_PAGE_OR_BLOG_SELECT_BLOG', "Chwazi post la blog ou vle efase");
// Popup Messages:
define('DELETE_PAGE_OR_BLOG_DELETE_BLOG_CONFIRM_1_MSG', "Èske ou w ke ou vle efase");
define('DELETE_PAGE_OR_BLOG_DELETE_BLOG_CONFIRM_2_MSG', "?");
define('DELETE_PAGE_OR_BLOG_DELETE_PAGE_CONFIRM_1_MSG', "Se asire w ke ou ou vle efase nan");
define('DELETE_PAGE_OR_BLOG_DELETE_PAGE_CONFIRM_2_MSG', "paj?");
define('DELETE_PAGE_OR_BLOG_RECALL_PLUGIN_CONFIRM_1_MSG', "Se asire w ke ou, ou vle sonje a");
define('DELETE_PAGE_OR_BLOG_RECALL_PLUGIN_CONFIRM_2_MSG', "ploge?");

///////////////////////// Copy/Raname Select Page /////////////////////////
// Buttons:
define('COPY_RENAME_PAGE_HEADING', "Kopi oswa Chanje non Paj");
define('COPY_RENAME_PAGE_COPY_RENAME_BTN', "Kopi / Chanje non");
// Console Text:
define('COPY_RENAME_PAGE_DISCARD_TEMPLATE_NOTE', "Jete fin vye granmoun modèl paj ak kreye nouvo");
define('COPY_RENAME_PAGE_RENAME_PAGE_LINK_NOTE', "Remak: Lòt non paj PA pral chanje nenpòt lyen ke ou te kreye. bagay ki nan meni pral mete ajou otomatikman, men ou pral bezwen chanje nenpòt lyen ki egziste sou nenpòt paj referans non an paj nouvo.");

///////////////////////// Copy/Raname Page /////////////////////////
// Buttons:
define('COPY_RENAME_PAGE_OVERWRITE_DESTINATION_BTN', "recouvrir destinasyon");
define('COPY_RENAME_PAGE_OVERWRITE_DESTINATION_RETAIN_TEMPLATE_BTN', "Recouvrir kontni destinasyon men kenbe destinasyon modèl");
define('COPY_RENAME_PAGE_OVERWRITE_DESTINATION_CREATE_NEW_TEMPLATE_BTN', "Recouvrir destinasyon ak kontni sous kreye nouvo modèl pou chak opsyon sit chwazi");
define('COPY_RENAME_PAGE_CANCEL_COPY_BTN', "Anile kopi yo epi retounen nan kopi a / chanje non konsole");
// Console Text:
define('COPY_RENAME_PAGE_PAGE_ALREADY_EXISTS', "deja egziste. Kisa ou vle fe?");
// Popup Messages:
define('COPY_RENAME_PAGE_FORGOT_TO_SELECT_PAGE_TO_RENAME_1_MSG', "Wouch! Ou bliye chwazi yon paj chanje non.");
define('COPY_RENAME_PAGE_FORGOT_TO_SELECT_PAGE_TO_RENAME_2_MSG', "epi chwazi yon paj chanje non.");
define('COPY_RENAME_PAGE_FORGOT_TO_ENTER_NEW_PAGE_NAME_1_MSG', "Wouch! Ou bliye antre nan yon non paj nouvo.");
define('COPY_RENAME_PAGE_FORGOT_TO_ENTER_NEW_PAGE_NAME_2_MSG', "ak antre nan yon non paj nouvo.");
define('COPY_RENAME_PAGE_COPY_ONTO_SELF_1_MSG', "Ou pa ka kopi yon paj sou tèt li. (Sof si ou te chwazi yo jete modèl la fin vye granmoun ak kreye yon nouvo.)");
define('COPY_RENAME_PAGE_COPY_ONTO_SELF_2_MSG', "ak antre nan yon non paj nouvo.");
define('COPY_RENAME_PAGE_ERROR_OPENING_NEW_PAGE_ERR', "Erè louvri nouvo dosye paj. Tanpri kontakte administratè sistèm ou an.");
define('COPY_RENAME_PAGE_ERROR_UPDATING_PAGE_NAME_REFERENCES_ERR', "Erè jour referans Non paj nan nouvo dosye paj. Tanpri kontakte administratè sistèm ou an.");
define('COPY_RENAME_PAGE_ERROR_CLOSING_NEW_PAGE_AFETR_REFERENCE_UPDATE_ERR', "Erè fèmen referans Non paj nan nouvo dosye paj. Tanpri kontakte administratè sistèm ou an.");
define('COPY_RENAME_PAGE_TO_RETURN_TO_COPY_RENAME_CONSOLE', "pou li retounen nan konsole a kopi / chanje non.");
define('COPY_RENAME_PAGE_RENAME_NEW_PAGE_ALREADY_EXISTS_1_ERR', "paj la");
define('COPY_RENAME_PAGE_RENAME_NEW_PAGE_ALREADY_EXISTS_2_ERR', "deja egziste. Ou pa ka chanje non");
define('COPY_RENAME_PAGE_RENAME_NEW_PAGE_ALREADY_EXISTS_3_ERR', "ak antre nan yon non destinasyon diferan.");
define('COPY_RENAME_PAGE_UNKNOWN_ERROR_ERR', "Gen kèk ki jan nou pa kapab detèmine si ou vle a kapab bay kopi oswa chanje non. Tanpri, ale retounen lakay yo epi chwazi yon operasyon nan lis la.");
define('COPY_RENAME_PAGE_RENAME_OLD_PAGE_NOT_FOUND_ERR', "pa jwenn. Tanpri kontakte administratè sistèm ou an.");
define('COPY_RENAME_PAGE_ERROR_RENAMING_PAGE_ERR', "Erè lòt non dosye-a. Tanpri kontakte administratè sistèm ou an.");
define('COPY_RENAME_PAGE_ERROR_OPENING_ORIGINAL_PAGE_ERR', "Erè louvri orijinal dosye paj. Tanpri kontakte administratè sistèm ou an.");
define('COPY_RENAME_PAGE_ERROR_WRITING_TO_NEW_PAGE_ERR', "Erè ekri kontni nan nouvo dosye paj. Tanpri kontakte administratè sistèm ou an.");
define('COPY_RENAME_PAGE_ERROR_CLOSING_NEW_PAGE_ERR', "Erè fèmen nouvo dosye paj. Tanpri kontakte administratè sistèm ou an.");
define('COPY_RENAME_PAGE_CANT_READ_ERR', "pa kapab li");

///////////////////////// Restore Page /////////////////////////
// Buttons:
define('RESTORE_PAGE_HEADING', "renmèt Page");
define('RESTORE_PAGE_SHOW_CONTENT_BTN', "Montre avantou");
define('RESTORE_PAGE_SHOW_CODE_BTN', "Montre Kòd");
// Console Text:
define('RESTORE_PAGE_SELECT_PAGE', "Chwazi paj la ou vle retabli");
define('RESTORE_PAGE_DELETE_FROM_HISTORY', "Efase soti nan Istwa");
// Popup Messages:
define('RESTORE_PAGE_DELETE_BACKUP_CONFIRM_1_MSG', "Èske ou sèten ou vle <b>efase</b> nan");
define('RESTORE_PAGE_DELETE_BACKUP_CONFIRM_2_MSG', "paj nan istwa a backup?");
define('RESTORE_PAGE_RESTORE_PAGE_CONFIRM_1_MSG', "Èske ou sèten ou vle <b>retabli</b> a");
define('RESTORE_PAGE_RESTORE_PAGE_CONFIRM_2_MSG', "paj?");

///////////////////////// Add Plugin to Page /////////////////////////
// Buttons:
define('ADD_PLUGIN_TO_PAGE_HEADING', "Enstale Plugin Nan Page");
define('ADD_PLUGIN_TO_PAGE_SELECT_PAGE_HEADING', "Chwazi Page");
define('ADD_PLUGIN_TO_PAGE_SELECT_PLUGIN_HEADING', "Chwazi Plugin");
// Console Text:
define('ADD_PLUGIN_TO_PAGE_PAGE_SELECTED', "paj chwazi");
define('ADD_PLUGIN_TO_PAGE_PLUGIN_SELECTED', "plugin chwazi");
// Popup Messages:
define('ADD_PLUGIN_TO_PAGE_PLUGIN_HAS_BEEN_ADDED_TO_PAGE_1_MSG', "nan");
define('ADD_PLUGIN_TO_PAGE_PLUGIN_HAS_BEEN_ADDED_TO_PAGE_2_MSG', "te plugin te mete nan nan");
define('ADD_PLUGIN_TO_PAGE_PLUGIN_HAS_BEEN_ADDED_TO_PAGE_3_MSG', "paj.");
define('ADD_PLUGIN_TO_PAGE_PAGE_OR_PLUGIN_NOT_SELECTED_1_MSG', "Wouch! Ou bliye chwazi yon paj ak / oswa yon Plugin.");
define('ADD_PLUGIN_TO_PAGE_PAGE_OR_PLUGIN_NOT_SELECTED_2_MSG', "epi chwazi yon paj ak yon Plugin.");
define('ADD_PLUGIN_TO_PAGE_ERROR_OPENING_PAGE_FILE_ERR', "Erè ouvèti paj dosye-a. Tanpri kontakte administratè sistèm ou an.");
define('ADD_PLUGIN_TO_PAGE_ERROR_UPDATING_PAGE_FILE_ERR', "Erè paj jour dosye-a. Tanpri kontakte administratè sistèm ou an.");
define('ADD_PLUGIN_TO_PAGE_ERROR_CLOSING_PAGE_FILE_ERR', "Erè fèmen paj dosye-a. Tanpri kontakte administratè sistèm ou an.");
define('ADD_PLUGIN_TO_PAGE_RETURN_TO_INSERT_PLUGIN_INTO_PAGE_CONSOLE_MSG', "pou li retounen nan insert-plugin-an-paj konsole la.");
define('ADD_PLUGIN_TO_PAGE_COULD_NOT_RENAME_MSG', "Pa t &#39;kapab chanje non");

///////////////////////// Mange Page Access /////////////////////////
// Buttons:
define('MANAGE_PAGE_ACCESS_HEADING', "Jere Restricted Paj &amp; Sit wèb Itilizatè yo");
define('MANAGE_PAGE_ACCESS_ADD_LOGIN_FIELDS_BTN', "Ajoute Login Itilizatè <br /> Jaden nan Tab");
define('MANAGE_PAGE_ACCESS_ASSIGN_WELCOME_MESSAGE_PAGE_BTN', "Bay Byenveni mesaj <br /> Page nan Tab Itilizatè");
// Console Text:
define('MANAGE_PAGE_ACCESS_RESTRICT_PAGE_ACCESS', "Mete restriksyon sou Page Aksè");
define('MANAGE_PAGE_ACCESS_APPROVE_ACCESSTO_USERS', "Apwouve Aksè nan Itilizatè yo");
define('MANAGE_PAGE_ACCESS_USER_TABLE_SETUP', "Itilizatè Table Enstalasyon");
define('MANAGE_PAGE_ACCESS_SHOW_LOGIN_LINKS_ALWAYS', "Montre Login <br /> lyen Toujou");
define('MANAGE_PAGE_ACCESS_REQUIRE_LOGIN', "mande pou Login");
define('MANAGE_PAGE_ACCESS_LOGIN_PAGE', "login Page");
define('MANAGE_PAGE_ACCESS_MESSAGE_PAGE', "mesaj Page");
define('MANAGE_PAGE_ACCESS_FIRST_LAST', "(Premye, siyati)");
define('MANAGE_PAGE_ACCESS_OPTIONAL', "(Si ou vle)");
define('MANAGE_PAGE_ACCESS_ADDITIONAL_FORMS_NOTE', "Itilizatè yo yo, se tipikman te ajoute nan fòm a (yo) kreye pou sit entènèt la. Fòm yo anba a yo se enkli yo ki pèmèt de sa nan itilizatè a entèfas a Breeze Sit wèb Builder pa administratè sit yo ak divinò pouvwa.");
// Popup Messages:
define('MANAGE_PAGE_ACCESS_DELETE_USER_CONFIRM_1_MSG', "Èske ou sèten ou vle efase itilizatè a");
define('MANAGE_PAGE_ACCESS_DELETE_USER_CONFIRM_2_MSG', "?");
define('MANAGE_PAGE_ACCESS_USER_DELETED_1_MSG', "itilizatè");
define('MANAGE_PAGE_ACCESS_USER_DELETED_2_MSG', "te efase");
define('MANAGE_PAGE_ACCESS_DELETE_ACCESS_LEVEL_CONFIRM_1_MSG', "Èske ou sèten ou vle efase nivo a aksè");
define('MANAGE_PAGE_ACCESS_DELETE_ACCESS_LEVEL_CONFIRM_2_MSG', "?");
define('MANAGE_PAGE_ACCESS_LOCATING_PAGE_RESTRICTIONS_MSG', "Lokalize restriksyon paj ...");
define('MANAGE_PAGE_ACCESS_COULD_NOT_UPDATE_PAGE_RESTRICTIONS_MSG', "Pa gen dosye yo te jwenn. Pa t &#39;kapab mete ajou restriksyon paj.");
define('MANAGE_PAGE_ACCESS_PAGE_RESTRICTIONS_UPDATED_MSG', "Page restriksyon mete ajou");
define('MANAGE_PAGE_ACCESS_UPDATING_PAGE_RESTRICTIONS_MSG', "paj Mete ajou restriksyon ...");
define('MANAGE_PAGE_ACCESS_COULD_NOT_UPDATE_USER_STATUS_MSG', "Pa gen dosye yo te jwenn. Pa t &#39;kapab mete ajou estati itilizatè.");
define('MANAGE_PAGE_ACCESS_USER_STATUS_UPDATED_MSG', "sitiyasyon Itilizatè mete ajou");
define('MANAGE_PAGE_ACCESS_UPDATING_USER_STATUS_MSG', "Mete ajou sitiyasyon itilizatè ...");
define('MANAGE_PAGE_ACCESS_COULD_NOT_MODIFY_TABLE_MSG', "Pa t &#39;kapab modifye tab");
define('MANAGE_PAGE_ACCESS_FIELDS_ADDED_TO_TABLE_MSG', "Jaden te ajoute sou tab");
define('MANAGE_PAGE_ACCESS_ADDING_FIELDS_TO_TABLE_MSG', "Ajoute jaden yo sou tab ...");
define('MANAGE_PAGE_ACCESS_WELCOME_MESSAGE_PAGE_ADDED_TO_TABLE_MSG', "Byenveni paj mesaj te ajoute sou tab");
define('MANAGE_PAGE_ACCESS_ADDING_WELCOME_MESSAGE_PAGE_TO_TABLE_MSG', "Ajoute akeyi paj mesaj sou tab ...");
define('MANAGE_PAGE_ACCESS_COULD_NOT_ADD_DELETE_ACCESS_LEVEL_MSG', "Pa t &#39;kapab ajoute oswa efase nivo aksè.");
define('MANAGE_PAGE_ACCESS_ACESS_LEVEL_RECORDS_MODIFIED_MSG', "dosye nivo Aksè modifye");
define('MANAGE_PAGE_ACCESS_CHANGING_ACCESS_LEVELS_MSG', "Chanje nivo aksè ...");
define('MANAGE_PAGE_ACCESS_LOCATING_ACCESS_LEVELS_MSG', "Lokalize nivo aksè ...");
define('MANAGE_PAGE_ACCESS_LOCATING_USERS_MSG', "Lokalize itilizatè ...");
define('MANAGE_PAGE_ACCESS_REQUIRED_FIELDS_MSG', "Asire w ke fòm nan w ap itilize pou itilizatè gen jaden yo ak &#39;imel&#39; non yo, &#39;user_id&#39; ak &#39;Modpas&#39;. Si yo te tab la ou chwazi kreye lè l sèvi avèk kont-kreyasyon fòm Plugin la, lè sa a sa yo jaden yo deja egziste nan tablo sa a.");
define('MANAGE_PAGE_ACCESS_RETRIEVING_PAGE_RESTRICTIONS_MSG', "Retwouve restriksyon paj ...");
define('MANAGE_PAGE_ACCESS_RETRIEVING_ACCESS_LEVELS_MSG', "Retwouve nivo aksè ...");
define('MANAGE_PAGE_ACCESS_RETRIEVING_USERS_MSG', "Retwouve itilizatè ...");
define('MANAGE_PAGE_ACCESS_ADDING_LOGIN_FIELDS_TO_TABLE_MSG', "Ajoute jaden yo login sou tab ...");
define('MANAGE_PAGE_ACCESS_ASSIGNING_WELCOME_MESSAGE_PAGE_TO_TABLE_MSG', "Plase akeyi paj mesaj sou tab ...");
define('MANAGE_PAGE_ACCESS_ADDING_ACCESS_LEVEL_MSG', "Ajoute nivo aksè ...");
define('MANAGE_PAGE_ACCESS_REMOVING_ACCESS_LEVEL_MSG', "Retire nivo aksè ...");
define('MANAGE_PAGE_ACCESS_NEW_USER_NOT_ADDED_ERR', "Yon erè te fèt. Itilizatè a nouvo pa te ajoute.");
define('MANAGE_PAGE_ACCESS_NEW_USER_CREATED_1_MSG', "nouvo itilizatè");
define('MANAGE_PAGE_ACCESS_NEW_USER_CREATED_2_MSG', "te kreye ak modpas");
define('MANAGE_PAGE_ACCESS_NEW_USER_CREATED_3_MSG', "ak yon nivo aksè nan");
define('MANAGE_PAGE_ACCESS_NEW_USER_CREATED_4_MSG', "pou");
define('MANAGE_PAGE_ACCESS_NEW_USER_CREATED_5_MSG', "ak imel");
define('MANAGE_PAGE_ACCESS_PASSWORD_CHANGED_1_MSG', "Modpas la pou itilizatè");
define('MANAGE_PAGE_ACCESS_PASSWORD_CHANGED_2_MSG', "gen te chanjman nan");
define('MANAGE_PAGE_ACCESS_USER_CHANGED_1_MSG', "itilizatè");
define('MANAGE_PAGE_ACCESS_USER_CHANGED_2_MSG', "te modifye ak yon nivo aksè nan");
define('MANAGE_PAGE_ACCESS_USER_CHANGED_3_MSG', ", Se yon non");
define('MANAGE_PAGE_ACCESS_USER_CHANGED_4_MSG', "ak yon imel nan");
define('MANAGE_PAGE_ACCESS_NO_DATA_FOUND_FOR_USER_ERR', "Erè: Pa gen done yo te jwenn pou ki itilizatè");
define('MANAGE_PAGE_ACCESS_NO_TABLE_SELECTED_ERR', "Ou dwe gen yon tab itilizatè chwazi si ou vle mande pou login jwenn aksè nan yon paj. Tanpri chwazi yon tab itilizatè epi eseye ankò.");
define('MANAGE_PAGE_ACCESS_NO_LOGIN_PAGE_SELECTED_ERR', "Ou dwe gen yon paj login chwazi si ou vle mande pou login jwenn aksè nan yon paj. Tanpri chwazi yon paj login epi eseye ankò. Si pa gen okenn paj login nan lis la, ou dwe premye kreye yon paj login quelle login Plugin la. Non a nan paj la login dwe gen ladan &#39;login&#39;.");


///////////////////////// Manage Page Attributes /////////////////////////
// Buttons:
define('MANAGE_PAGE_ATTRIBUTES_HEADING', "Jere Page Atribi");
define('MANAGE_PAGE_ATTRIBUTES_TEMPLATE_HEADING', "Modèl layout");
// Console Text:
define('MANAGE_PAGE_ATTRIBUTES_PAGE_ATTRIBUTES', "Page Atribi");
define('MANAGE_PAGE_ATTRIBUTES_USE_PAGE_TABLE_STRUCTURES', "Sèvi ak Page Table Estrikti");
define('MANAGE_PAGE_ATTRIBUTES_USE_PAGE_TABLE_STRUCTURES_FOR_MOBILE', "Sèvi ak Estrikti Page Table pou mobil");
define('MANAGE_PAGE_ATTRIBUTES_CALL_BODY_ONLOAD_FUNCTION', "Rele Kò onlod Fonksyon");
define('MANAGE_PAGE_ATTRIBUTES_DISABLE_SITE_STYLES_WHEN_EDITING', "Enfim Sit Styles lè Korije");
define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_HEAD', "Antre Default Head nan Custom tèt");
define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_HEADER', "Antre Default Header nan Custom Header");
define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_TOP', "Antre Default Top nan Custom Top");
define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_LEFT', "Antre Default Left nan Custom Left");
define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_RIGHT', "Antre Default Dwa nan Custom Dwa");
define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_BOTTOM', "Antre Default anba nan Custom anba");
define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_FOOTER', "Antre Default Footer nan Custom Footer");
// Popup Messages:
define('MANAGE_PAGE_ATTRIBUTES_ERROR_RETRIEVING_PAGE_ATTRIBUTES_ERR', "Te gen yon erè retwouve atribi ki paj.");
define('MANAGE_PAGE_ATTRIBUTES_PAGE_ATTRIBUTES_SAVED_MSG', "atribi ki paj yo te sove.");
define('MANAGE_PAGE_ATTRIBUTES_ERROR_SAVING_PAGE_ATTRIBUTES_ERR', "Te gen yon erè ekonomize atribi ki paj.");
define('MANAGE_PAGE_ATTRIBUTES_ERROR_ONLOAD_ERR', "Si yo &#39;Rele Kò onlod Fonksyon&#39; tcheke, fonksyon an pa kapab vid.");

///////////////////////// Upload Template /////////////////////////
// Buttons:
define('UPLOAD_TEMPLATE_HEADING', "Voye Modèl");
// Console Text:
define('UPLOAD_TEMPLATE_CONFIRM_MSG', "Èske ou w ke ou vle Upload yon modèl nouvo? Kontinye pral ranplase sit ou ye kounye a ak chanjman sa yo yo se irevokabl. Y ap ba ou yon chwa si wi ou non ou vle kenbe kontni paj ou a, men yo pral tèm ak fwontyè kontni an zòn dwe ranplase.");
define('RERUN_WIZARD_RUN_WIZARD_CONFIRM_MSG', "Èske ou sèten ou vle re-kouri sòsye an? Kontinye pral ranplase sit ou ye kounye a ak chanjman sa yo yo se irevokabl. Y ap ba ou yon chwa si wi ou non ou vle kenbe kontni paj ou a, men yo pral tèm ak fwontyè kontni an zòn dwe ranplase.");
define('UPLOAD_TEMPLATE_BUILDING_SITE_MSG', "sit bilding ak modèl ....");
define('UPLOAD_TEMPLATE_WHEN_COMPLETE_SCROLL_TO_BOTTOM_MSG', "Lè li fini, woulo liv nan fon yo ka kontinye.");
define('UPLOAD_TEMPLATE_ALLOWED_FILE_TYPE_MSG', "Se sèlman gzipped dosye goudwon ​​gen dwa yo dwe Uploaded, sa vle di &#39;template_105.tgz&#39; oswa &#39;template_26.tar.gz&#39;. tanpri klike");
define('UPLOAD_TEMPLATE_COPYING_USER_FILES_MSG', "dosye Kopye itilizatè ...");
define('UPLOAD_TEMPLATE_COPYING_PAGES_MSG', "paj Kopye ...");
define('UPLOAD_TEMPLATE_COPYING_IMAGES_MSG', "Kopye imaj ...");
define('UPLOAD_TEMPLATE_COPYING_CSS_MSG', "Kopye CSS ...");
define('UPLOAD_TEMPLATE_COPYING_MEDIA_MSG', "Kopye medya ...");
define('UPLOAD_TEMPLATE_COPYING_FLASH_MSG', "Kopye flash ...");
define('UPLOAD_TEMPLATE_COPYING_SCRIPTS_MSG', "Kopye Scripts ...");
define('UPLOAD_TEMPLATE_COPYING_XML_MSG', "Kopye XML ...");
define('UPLOAD_TEMPLATE_UNABLE_TO_OPEN_DOC_ROOT_ERR', "Kapab louvri rasin dokiman.");
define('UPLOAD_TEMPLATE_COULD_NOT_RENAME_ERR', "Pa t &#39;kapab chanje non");
define('UPLOAD_TEMPLATE_CANT_CREATE_ERR', "Pa ka kreye");
define('UPLOAD_TEMPLATE_ERROR_UPLOADING_FILE_ERR', "Te gen yon erè uploading dosye a.");
define('UPLOAD_TEMPLATE_TO_CONTINUE_MSG', "yo ka kontinye.");
define('UPLOAD_TEMPLATE_SQL_FILE_MSG', "SQL dosye ...");
define('UPLOAD_TEMPLATE_SQL_FILE_NAME_NOT_DEFINED_ERR', "Fatal erè: File name SQL se pa sa defini.");
define('UPLOAD_TEMPLATE_SQL_MSG', "SQL ...");
define('UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG', "ranje (yo) ki afekte yo.");
define('UPLOAD_TEMPLATE_SELECT_TEMPLATE_FROM_YOUR_COMPUTER', "Chwazi modèl la ou vle enstale nan òdinatè w lan:");
define('UPLOAD_TEMPLATE_DELETE_ALL_PAGES', "Efase tout paj");
// Popup Messages:
define('UPLOAD_TEMPLATE_DELETE_ALL_PAGES_CONFIRM_MSG', "Èske ou sèten ou vle efase tout nan kontni paj ou a?");
define('UPLOAD_TEMPLATE_UPLOADING_TEMPLATE_PLEASE_WAIT_MSG', "Uploading modèl, tanpri, tann ...");
define('UPLOAD_TEMPLATE_UPLOADING', "Uploading modèl, tanpri, tann ...");

///////////////////////// Admin Function Select /////////////////////////
// Buttons:
define('ADMIN_FUNCTION_SELECT_HEADING', "Jere Itilizatè yo ak Opsyon Sit");
define('ADMIN_FUNCTION_SELECT_MANAGE_USERS_BTN', "jere Itilizatè yo");
define('ADMIN_FUNCTION_SELECT_CHANGE_SITE_OPTIONS_BTN', "Chanje Sit Opsyon");
define('ADMIN_FUNCTION_SELECT_RESTRICT_PAGE_EDITING_ACCESS_BTN', "Mete restriksyon sou Page Korije Aksè");
define('ADMIN_FUNCTION_SELECT_GENERATE_SITE_MAP_BTN', "Jenere Plan sit la");
define('ADMIN_FUNCTION_SELECT_PRUNE_PAGE_EDIT_BACKUP_TABLE_BTN', "Koupe Page Edit sovgad Table");
define('ADMIN_FUNCTION_SELECT_PRUNE_BACKUP_FILES_BTN', "Koupe CSS, kat jeyografik sit, <br /> ranpli modifye backup, ak <br /> JavaScript dosye meni backup");
define('ADMIN_FUNCTION_SELECT_CLEAR_CUSTOM_CLASSES_BTN', "Klè tout Custom CSS Klas");
define('ADMIN_FUNCTION_SELECT_INSTALL_PLUGIN_BTN', "enstale Plugin");
define('ADMIN_FUNCTION_SELECT_RECALL_PLUGIN_BTN', "Rapèl Plugin");
define('ADMIN_FUNCTION_SELECT_INSTALL_UPDATE_BTN', "enstale Mizajou");
define('ADMIN_FUNCTION_SELECT_RUN_SQL_BTN', "Kouri SQL");
define('ADMIN_FUNCTION_SELECT_SHOW_SERVER_INFO_BTN', "Montre sèvè Enfòmasyon");
define('ADMIN_FUNCTION_SELECT_DEACTIVATE_WEBSITE_BTN', "De-aktive Sit wèb");
define('ADMIN_FUNCTION_SELECT_ACTIVATE_WEBSITE_BTN', "aktive Sit wèb");
// Console Text:
define('ADMIN_FUNCTION_SELECT_PRUNE_PAGE_EDIT_BACKUP_TABLE_TO', "Koupe paj modifye backup tab yo");
define('ADMIN_FUNCTION_SELECT_SELECT_PLUGIN_TO_RECALL', "Chwazi Plugin la ou vle sonje");
// Popup Messages:
define('ADMIN_FUNCTION_SELECT_DEACTIVATE_SITE_CONFIRM_MSG', "Èske ou vle pran sit ou nan liy?");
define('ADMIN_FUNCTION_SELECT_ACTIVATE_SITE_CONFIRM_MSG', "ou vle pran sit ou ap viv?");
define('ADMIN_FUNCTION_SELECT_BACKUP_FILES_HAVE_BEEN_PRUNED_MSG', "CSS, kat jeyografik sit, ak JavaScript meni dosye backup yo te koupe.");

///////////////////////// Manage Users /////////////////////////
// Buttons:
define('MANAGE_USERS_HEADING', "jere Itilizatè yo");
// Console Text:
define('MANAGE_USERS_SSL_NOT_PRESENT_WARNING', "<b>AVÈTISMAN SOU:</b> Ou affichage konsole sa a ak yon koneksyon kode. Si w ap ajoute itilizatè oswa chanje modpas li rekòmande ke ou itilize yon koneksyon chiffres. Pou chanje an yon koneksyon chiffres, klike sou");
define('MANAGE_USERS_INVALID_CERTIFICATE_NOTE', "Remak: Sètifika a SSL yo gen dwa pa valab. Si sa a se ka a, jis aksepte sètifika a de tout fason yo e yo kontinye koneksyon an chiffres. Epitou, kèk serveurs pa gen sètifika SSL enstale, se konsa li pa ta ka posib yo wè konsole sa a chiffres. Si klike sou lyen ki pa travay jis klike sou bouton an tounen.");
// Popup Messages:
define('MANAGE_USERS_DELETE_USER_CONFIRM_1_MSG', "Se asire w ke ou ou vle efase itilizatè a");
define('MANAGE_USERS_DELETE_USER_CONFIRM_2_MSG', "?");
define('MANAGE_USERS_USER_DELETED_1_MSG', "itilizatè");
define('MANAGE_USERS_USER_DELETED_2_MSG', "te efase");
define('MANAGE_USERS_NO_USERS_FOUND_ERR', "Erè: Non itilizatè jwenn");
define('MANAGE_USERS_NO_DATA_FOUND_FOR_USER_ERR', "Erè: Pa gen done yo te jwenn pou ki itilizatè");
define('MANAGE_USERS_USER_NOT_ADDED_ERR', "Yon erè te fèt. Itilizatè a nouvo pa te ajoute.");
define('MANAGE_USERS_NEW_USER_ADDED_1_MSG', "nouvo itilizatè");
define('MANAGE_USERS_NEW_USER_ADDED_2_MSG', "te kreye ak modpas");
define('MANAGE_USERS_NEW_USER_ADDED_3_MSG', "ak yon nivo aksè nan");
define('MANAGE_USERS_NEW_USER_ADDED_4_MSG', "pou");
define('MANAGE_USERS_NEW_USER_ADDED_5_MSG', "ak imel");
define('MANAGE_USERS_PASSWORD_CHANGED_1_MSG', "Modpas la pou itilizatè");
define('MANAGE_USERS_PASSWORD_CHANGED_2_MSG', "gen te chanjman nan");
define('MANAGE_USERS_USER_MODIFIED_1_MSG', "itilizatè");
define('MANAGE_USERS_USER_MODIFIED_2_MSG', "te modifye ak yon nivo aksè nan");
define('MANAGE_USERS_USER_MODIFIED_3_MSG', ", Se yon non");
define('MANAGE_USERS_USER_MODIFIED_4_MSG', "ak yon imel nan");
define('MANAGE_USERS_NO_TABLE_TO_ADD_USER_TO_1_ERR', "Ou dwe chwazi yon tab premye yo ajoute yon itilizatè yo.");
define('MANAGE_USERS_NO_TABLE_TO_ADD_USER_TO_2_ERR', "yo chwazi yon tab epi eseye ankò.");
define('MANAGE_USERS_USER_ALREADY_EXISTS_ERR', "antre nan yon non itilizatè diferan.");
define('MANAGE_USERS_NO_TABLE_TO_CHANGE_USER_PASSWORD_ERR', "Ou dwe chwazi yon tab premye chanje modpas la nan yon itilizatè.");
define('MANAGE_USERS_NO_TABLE_TO_DELETE_USER_FROM_ERR', "Ou dwe chwazi yon tab premye yo efase yon itilizatè nan.");

///////////////////////// Manage SIte Options /////////////////////////
// Buttons:
define('MANAGE_SITE_OPTIONS_HEADING', "Chanje Sit Opsyon");
// Console Text:
// Popup Messages:
define('MANAGE_SITE_OPTIONS_OPTIONS_SAVED_MSG', "Opsyon ki disponib nan yo te sove.");
define('MANAGE_SITE_OPTIONS_ERROR_SAVING_OPTIONS_ERR', "Te gen yon erè ekonomize opsyon yo.");

///////////////////////// Restrict Page Editing Access /////////////////////////
// Buttons:
define('RESTRICT_PAGE_EDITING_HEADING', "Mete restriksyon sou Aksè nan Korije Paj pou Restricted Itilizatè yo");
// Console Text:
// Popup Messages:
define('RESTRICT_PAGE_EDITING_RESTRICTIONS_SAVED_MSG', "Page restriksyon yo te sove.");

///////////////////////// Generate Site Map /////////////////////////
// Buttons:
define('GENERATE_SITE_MAP_HEADING', "Jenere Plan sit la");
// Console Text:
define('GENERATE_SITE_MAP_GENERATING', "Génération kat jeyografik sit ...");
define('GENERATE_SITE_MAP_COULD_NOT_RENAME_1_ERR', "Pa t &#39;kapab chanje non");
define('GENERATE_SITE_MAP_COULD_NOT_RENAME_2_ERR', "");
define('GENERATE_SITE_MAP_ERROR_CREATING_SITEMAP_ERR', "Erè sit creatng kat jeyografik.");
define('GENERATE_SITE_MAP_SITEMAP_REBUILD_COMPLETE', "Sitemap rebati konplè!");
define('GENERATE_SITE_MAP_SITEMAP_CREATION_COMPLETE', "Sitemap kreyasyon konplè!");
define('GENERATE_SITE_MAP_ROBOT_FILE_CREATED', "dosye robo kreye!");
define('GENERATE_SITE_MAP_CANT_CREATE_ERR', "Pa ka kreye");

///////////////////////// Install Plugin /////////////////////////
// Buttons:
define('INSTALL_PLUGIN_HEADING', "enstale Plugin");
// Console Text:
define('INSTALL_PLUGIN_PLEASE_ENTER_PASSWORD_FOR_ADMIN', "Tanpri antre modpas la pou kont itilizatè ou");
define('INSTALL_PLUGIN_SELECT_PLUGIN_FROM_YOUR_COMPUTER', "Chwazi Plugin la ou vle enstale nan òdinatè w lan");
define('INSTALL_PLUGIN_INSTALLING_PLUGIN', "Enstale Plugin ....");
define('INSTALL_PLUGIN_WRONG_FILE_TYPE_MSG', "Se sèlman dosye konpresè oswa gzipped dosye goudwon ​​gen dwa yo dwe Uploaded, sa vle di &#39;plugin.zip&#39; oswa &#39;plugin.tgz&#39; oswa &#39;plugin.tar.gz&#39;. tanpri klike");
define('INSTALL_PLUGIN_EXTRACTING_FILES', "Èkstraksyon dosye ...");
define('INSTALL_PLUGIN_ERROR_EXTRACTING_FILES_1_ERR', "Te gen yon erè èkstraksyon dosye yo nan dosye postal ou.");
define('INSTALL_PLUGIN_ERROR_EXTRACTING_FILES_1A_ERR', "Te gen yon erè èkstraksyon dosye yo nan dosye tar.gz ou yo.");
define('INSTALL_PLUGIN_ERROR_EXTRACTING_FILES_1B_ERR', "Te gen yon erè èkstraksyon dosye yo nan dosye goudwon ​​ou yo.");
define('INSTALL_PLUGIN_COPYING_FILES', "Kopye dosye ...");
define('INSTALL_PLUGIN_PLUGIN_INSTALLATION_COMPLETE', "Plugin enstalasyon se comlplete.");
define('INSTALL_PLUGIN_ADD_NEW_BUTTON_TO_MENU_MSG', "yo ajoute nouvo bouton Plugin meni.");
define('INSTALL_PLUGIN_ERROR_UPLOADING_FILE_ERR', "Te gen yon erè uploading dosye a.");
// Popup Messages:

///////////////////////// Install Update /////////////////////////
// Buttons:
define('INSTALL_UPDATE_HEADING', "enstale Mizajou");
// Console Text:
define('INSTALL_UPDATE_SELECT_UPDATE_FROM_YOUR_COMPUTER', "Chwazi aktyalizasyon a ou vle enstale nan òdinatè w lan");
define('INSTALL_UPDATE_INSTALLING_UPDATE', "Enstale aktyalizasyon ....");
define('INSTALL_UPDATE_WRONG_FILE_TYPE_MSG', "Se sèlman gzipped dosye goudwon ​​oswa dosye konpresè gen dwa yo dwe Uploaded, sa vle di &#39;breeze_update_x.x.xx.tgz&#39; oswa &#39;breeze_update_x.x.xx.tar.gz&#39; oswa &#39;breeze_update_x.x.xx.zip&#39;. tanpri klike");
define('INSTALL_UPDATE_UPDATE_INSTALLATION_COMPLETE', "enstalasyon Mizajou se konplè.");
define('INSTALL_UPDATE_REFRESH_MAIN_MENU', "rafrechi meni prensipal la.");
// Popup Messages:
define('INSTALL_UPDATE_NEW_VERSION_AVAILABLE', "Gen yon nouvo vèsyon an Sit wèb Builder a Breeze disponib. ou vle mete ajou kounye a? <br /><p class='medium_message' style='text-align:left;'> Mesaj sa a ap parèt Everytime ou louvri Breeze la jiskaske li se mete ajou. Si vèsyon Breeze ou vin plis pase yon vèsyon soti nan dat, ou yo ap sispann resevwa mesaj sa yo epi ou ap bezwen fè dènye incrémentielle semi-manyèlman. </p>");
define('INSTALL_UPDATE_VERSION_ERROR_ERR', "Eseye fè otomatik aktyalizasyon, men gen yon dezekilib ant vèsyon anvan, vèsyon vèsyon dosye ak vèsyon baz done.");

///////////////////////// Run SQL /////////////////////////
// Buttons:
define('RUN_SQL_HEADING', "Kouri SQL");
// Console Text:
define('RUN_SQL_PASTE_SQL_MSG', "Kole oswa antre nan deklarasyon SQL ou (yo) nan fenèt la pi wo a. Lè sa a, klike sou &quot;soumèt&quot;.");
define('RUN_SQL_SQL_COMMAND_DELIMITERS_NOTE', "Remak: Yo dwe fè tout lòd SQL dwe sispann pa yon pwenvigil (;). Liy kòmanse ak (-) oswa (//) ap dwe trete kòm kòmantè.");

///////////////////////// Javascript Menu Params and Styles /////////////////////////
// Popup Messages:
define('JS_MENU_PARAM_NO_PACAMETERS_1_ERR', "Pa gen paramèt yo te mete.");
define('JS_MENU_PARAM_NO_PACAMETERS_2_ERR', "yo ale retounen lakay yo epi ranpli nan paramèt yo.");
define('JS_MENU_STYLES_ERROR_SAVING_RECORD_ERR', "Erè te fèt eseye ekonomize dosye");
define('JS_MENU_CODE_REMOVE_CODE_CONFIRM_1_MSG', "Se asire w ke ou ou vle retire kòd la meni JavaScript ki soti nan");
define('JS_MENU_CODE_REMOVE_CODE_CONFIRM_2_MSG', "?");

///////////////////////// Options /////////////////////////
// Strings:
define('OPTIONS_TEMPLATE', "modèl");
define('OPTIONS_FORCE_PAGE_NAME_TO_LOWER_CASE', "Force Page Non Pou Lower Ka");
define('OPTIONS_ENABLE_WIZARD', "pèmèt Sòsye");
define('OPTIONS_RUN_WIZARD_LOCAL', "Kouri Sòsye Lokal (Tcheke sèlman si modèl repozitwa ak enstalasyon Breeze yo sou menm sèvè.)");
define('OPTIONS_ENABLE_FILE_MANAGER_FOR_RESTRICTED_USERS', "Pèmèt Manadjè File pou Itilizatè yo Restricted");
define('OPTIONS_ACTIVATE_NEW_USERS_AUTOMATICALLY', "Aktive Nouvo Itilizatè yo Otomatikman");
define('OPTIONS_USE_TABLE_STRUCTURES', "Estrikti Sèvi ak Table");
define('OPTIONS_USE_TABLE_STRUCTURES_ON_MOBILE', "Sèvi ak Estrikti Table sou mobil");
define('OPTIONS_CREATE_ACCOUNT_LINK_TEXT', "Kreye Kont Link Tèks");
define('OPTIONS_LOGIN_LINK_TEXT', "Login Link Tèks");
define('OPTIONS_MY_ACCOUNT_LINK_TEXT', "Mwen Tèks Link Kont");
define('OPTIONS_LOGOUT_LINK_TEXT', "Logout Link Tèks");
define('OPTIONS_CREATE_ACCOUNT_LINK', "Kreye Kont Link Tèks");
define('OPTIONS_LOGIN_LINK', "Login Link Tèks");
define('OPTIONS_MY_ACCOUNT_LINK', "Mwen Tèks Link Kont");
define('OPTIONS_LOGOUT_REDIRECT_OVERRIDE', "Logout Redirect Depase");
define('OPTIONS_EDITOR_SOURCE_VIEW_THEME', "Editè Sous View Tèm");
define('OPTIONS_BREEZE_WEBSITE_BUILDER_THEME', "Briz Sit wèb Builder Tèm");
define('OPTIONS_LOCKOUT_CLEAR_ALL_CUSTOM_CSS_CLASSES', "Verouyaj Klè tout Custom CSS Klas");
define('OPTIONS_LOCKOUT_COPY_STYLE_SHEET_TO_MOBILE', "Verouyaj Kopi Style Fèy mobil");

////////////////////// Manage Custom Fonts /////////////////////////////////////
// Buttons:
define('MANAGE_CUSTOM_FONTS_HEADING', "Jere Custom Polis");
// Console Text:
define('MANAGE_CUSTOM_FONTS_ADD_FONT', "ajoute Font");
define('MANAGE_CUSTOM_FONTS_DELETE_FONT', "Debarase m de Font");
define('MANAGE_CUSTOM_FONTS_NO_FONTS', "-Pa gen koutim fonts-");
define('MANAGE_CUSTOM_FONTS_STRETCH', "detire kò");
define('MANAGE_CUSTOM_FONTS_STYLE', "Style");
define('MANAGE_CUSTOM_FONTS_WEIGHT', "pwa");
// Popup Messages:
define('MANAGE_CUSTOM_FONTS_GET_FONTS_MSG', "Lè w polis ...");
define('MANAGE_CUSTOM_FONTS_GET_FONTS_COMPLETE_MSG', "Pepleman polis konplè.");
define('MANAGE_CUSTOM_FONTS_ADDING_FONT_MSG', "Ajoute font ...");
define('MANAGE_CUSTOM_FONTS_ADDING_FONT_COMPLETE_MSG', "Ajoute font konplè.");
define('MANAGE_CUSTOM_FONTS_ADDING_FONT_1_ERR', "font ak sous");
define('MANAGE_CUSTOM_FONTS_ADDING_FONT_2_ERR', "deja egziste.");
define('MANAGE_CUSTOM_FONTS_ADDING_FONT_UPLOAD_ERR', "Padon, te gen yon erè uploading font ou yo.");
define('MANAGE_CUSTOM_FONTS_ADDING_FONT_FILE_TYPE_ERR', "Padon, sèlman tf, otf, woff, WOFF2, SVG &amp; EOT dosye gen dwa.");
define('MANAGE_CUSTOM_FONTS_DELETE_FONT_CONFIRM_1_MSG', "Èske ou sèten ou vle efase nan");
define('MANAGE_CUSTOM_FONTS_DELETE_FONT_CONFIRM_2_MSG', "font ak sous");
define('MANAGE_CUSTOM_FONTS_DELETE_FONT_CONFIRM_3_MSG', "?");
define('MANAGE_CUSTOM_FONTS_DELETE_FONT_COMPLETE_MSG', "Font efase.");

////////////////////// Clear All Custom CSS Classes /////////////////////////////////////
// Buttons:
define('CLEAR_CUSTOM_CSS_CLASSES_HEADING', "Klè Klas Custom CSS");
// Console Text:
define('CLEAR_CUSTOM_CSS_CLASSES_ALL_STYLE_SHEETS', "Tout Style Dra");
// Popup Messages:
define('CLEAR_CUSTOM_CSS_CLASSES_WARNING_MSG', "AVÈTISMAN SOU: Proceding ak operasyon sa a pral trè pwofondman afekte sit entènèt ou. Chanjman sa a pa ka undone. Èske ou sèten ou vle kontinye?");
define('CLEAR_CUSTOM_CSS_CLASSES_WARNING_2_MSG', "AVÈTISMAN SOU: Sa a se operasyon gen entansyon ede nan reseting sit entènèt ou, oswa yon Plugin patikilye oswa meni nan défaut faktori. <br /> Chanjman sa a pa ka undone. Sa a se avètisman dènye ou. ou vle kontinye?");
define('CLEAR_CUSTOM_CSS_CLASSES_START_MSG', "Netwaye klas CSS koutim ...");
define('CLEAR_CUSTOM_CSS_CLASSES_COMPLETE_MSG', "Netwaye klas koutim CSS konplè.");
define('CLEAR_CUSTOM_CSS_CLASSES_COMPLETE_ERR', "Te gen yon erè netwaye klas yo koutim CSS.");

////////////////////// Backup/Restore /////////////////////////////////////
// Buttons:
define('BACKUP_RESTORE_HEADING', "Sovgad ak restore Sit");
// Console Text:
define('BACKUP_RESTORE_SELECT_BACKUP', "Chwazi sovgad YO PRAL MODÈNIZE");
define('BACKUP_RESTORE_SELECT_BACKUP_TO_UPLOAD', "Chwazi sovgad la ou vle retabli nan òdinatè w lan");
define('BACKUP_RESTORE_DELETE_BACKUP', "Debarase m de backup");
define('BACKUP_RESTORE_RETAIN_MEDIA', "Rantre retabli imaj, ak medya ak aktyèl");
define('BACKUP_RESTORE_UPLOAD_LARGE_BKUPS_MSG', "Uploading dosye backup pi gran pase 300 megabit ka febli. Si sa rive, ftp dosye backup ou nan katab la &#39;backup&#39; anba public_html ak rafrechi konsole sa a.");
// Popup Messages:
define('BACKUP_RESTORE_CREATING_BACKUP_PLEASE_WAIT_MSG', "Fè bak sit, tanpri, tann ...");
define('BACKUP_RESTORE_UPLOADING_BACKUP_PLEASE_WAIT_MSG', "Uploading backup, tanpri, tann ...");
define('BACKUP_RESTORE_RESTORING_WEBSITE', "Restore sit entènèt .... Scroll jouk anba lè konplè.");
define('BACKUP_RESTORE_RESTORE_CONFIRM_1_MSG', "Èske ou sèten ou vle retabli soti nan la");
define('BACKUP_RESTORE_RESTORE_CONFIRM_2_MSG', "backup dosye?");
define('BACKUP_RESTORE_DELETE_BACKUP_CONFIRM_MSG', "Èske ou sèten ou vle efase nan");
define('BACKUP_RESTORE_DELETE_BACKUP_SUCCESS_MSG', "te sovgad dosye efase.");
define('BACKUP_RESTORE_DELETE_BACKUP_ERROR_ERR', "Te gen yon erè efase dosye a backup.");
define('BACKUP_RESTORE_ERROR_CREATING_FOLDER_ERR', "Echwe pou pou kreye");
define('BACKUP_RESTORE_ERROR_ERROR_WRITING_FILE_ERR', "Pa ka ekri nan pote");
define('BACKUP_RESTORE_BACKUP_COMPLETE_MSG', "Sovgad se konplè!");
define('BACKUP_RESTORE_BACKUP_READY_FOR_DOWNLOAD_1_MSG', "backup ou a pare pou download.");
define('BACKUP_RESTORE_BACKUP_READY_FOR_DOWNLOAD_2_MSG', "nan download backup ou yo.");
define('BACKUP_RESTORE_RETURN_TO_MSG', "Retounen nan sovgad la / Renmèt Console");
define('BACKUP_RESTORE_WRONG_FILE_TYPE_1_MSG', "Se sèlman dosye konpresè oswa gzipped dosye goudwon ​​gen dwa yo dwe Uploaded, sa vle di &#39;backup_54121247.zip&#39; oswa &#39;backup_54121247.tgz&#39; oswa &#39;backup_54121247.tar.gz&#39;. tanpri klike");
define('BACKUP_RESTORE_RESTORE_COMPLETE', "restorasyon Sit se kounye a konplè.");
define('BACKUP_RESTORE_DUMPING_DATABASE', "Moun ap jete fatra baz done ...");
define('BACKUP_RESTORE_ZIPPING_FILES', "dosye achiv ...");



///////////////// Standard words and phrases ///////////////////////
define('WELCOME_WORD', "Byenveni");
define('ACCESS_LEVEL_WORD', "Aksè Nivo");
define('YES_WORD', "Wi");
define('NO_WORD', "Pa gen");
define('SUBMIT_WORD', "soumèt");
define('OK_WORD', "OK");
define('CANCEL_WORD', "Anile");
define('VERSION_WORD', "Version");
define('USERID_WORD', "itilizatè ID");
define('USERNAME_WORD', "Non itilizatè");
define('PASSWORD_WORD', "Modpas");
define('EMAIL_WORD', "Imèl");
define('NAME_WORD', "Non itilizatè");
define('DASHBOARD_WORD', "Dach");
define('SAVE_AS_WORD', "Save kòm");
define('CREATE_WORD', "Kreye");
define('UPDATE_WORD', "Mizajou");
define('REQUIRED_WORD', "mande");
define('OPTIONAL_WORD', "si ou vle");
define('PLUGINS_WORD', "plugins");
define('RIGHT_WORD', "dwat");
define('LEFT_WORD', "kite");
define('TOP_WORD', "tèt");
define('BOTTOM_WORD', "anba");
define('HEADER_WORD', "header");
define('FOOTER_WORD', "footer");
define('HEAD_WORD', "tèt");
define('ERROR_WORD', "Erè");
define('ERROR_CAPS_WORD', "eRÈ");
define('HERE_WORD', "isit la");
define('NEW_WORD', "nouvo");
define('DESCRIPTION_WORD', "Deskripsyon");
define('DATE_WORD', "Mizajou");
define('LINK_WORD', "Link");
define('TARGET_WORD', "Sib");
define('ACTIVE_WORD', "aktif");
define('USER_TABLE_WORD', "Table itilizatè");
define('HEADER_1ST_CAP_WORD', "header");
define('TOP_1ST_CAP_WORD', "Top");
define('LEFT_1ST_CAP_WORD', "Left");
define('RIGHT_1ST_CAP_WORD', "Dwa");
define('BOTTOM_1ST_CAP_WORD', "anba");
define('FOOTER_1ST_CAP_WORD', "footer");
define('HEAD_1ST_CAP_WORD', "Head");
define('VERTICAL_WORD', "vètikal");
define('HORIZONTAL_WORD', "Kouche plat");
define('OFFSET_WORD', "Offset");
define('POSITION_WORD', "pozisyon");
define('POSITIONING_WORD', "Pozisyon");
define('ABSOLUTE_WORD', "absoli");
define('RELATIVE_WORD', "Relative");
define('WIDTH_WORD', "Lajè");
define('HEIGHT_WORD', "Tay");
define('PROPORTIONAL_WORD', "pwopòsyonèl");
define('PADDING_WORD', "ranbouraj");
define('ORIENTATION_WORD', "Oryantasyon");
define('CENTER_WORD', "sant");
define('JUSTIFY_WORD', "jistifye");
define('FONT_WORD', "font");
define('SIZE_WORD', "Kantite moun ki");
define('WEIGHT_WORD', "pwa");
define('ITALIC_WORD', "Italic");
define('UNDERLINE_WORD', "Souliyen");
define('OVERLINE_WORD', "ovèrlin");
define('LINETHROUGH_WORD', "Linethrough");
define('BLINK_WORD', "bat je l");
define('OBLIQUE_WORD', "Oblik");
define('SHADOW_WORD', "lonbraj");
define('COLOR_WORD', "Koulè");
define('X_OFFSET_WORD', "X-Offset");
define('Y_OFFSET_WORD', "Y-Offset");
define('BLUR_WORD', "flou");
define('OPACITY_WORD', "stupidity");
define('WEBSAFE_WORD', "websafe");
define('NA_WORD', "PR");
define('NORMAL_WORD', "nòmal");
define('BOLD_WORD', "Bold");
define('BOLDER_WORD', "odasyeu");
define('LIGHTER_WORD', "Pi lejè");
define('INITIAL_WORD', "Inisyal");
define('INHERIT_WORD', "eritye");
define('INITIAL_LC_WORD', "premye");
define('INHERIT_LC_WORD', "eritye");
define('RGB_WORD', "#RRGGBB");
define('TEXT_WORD', "Tèks");
define('ALIGN_WORD', "aliman");
define('BACKGROUND_WORD', "Jan nou koumanse");
define('BORDER_WORD', "Border");
define('SPREAD_WORD', "Gaye");
define('INSET_WORD', "Carytown");
define('BASELINE_WORD', "debaz");
define('SUB_WORD', "Gwoup");
define('SUPER_WORD', "Super");
define('MIDDLE_WORD', "Middle");
define('NONE_WORD', "Okenn");
define('RADIUS_WORD', "reyon");
define('MARGIN_WORD', "maj");
define('AUTO_WORD', "Auto");
define('DISPLAY_WORD', "Display");
define('VISIBILITY_WORD', "vizibilite");
define('OVERFLOW_WORD', "Depatman");
define('FLOAT_WORD', "flote");
define('CLIPPING_WORD', "Taye");
define('IMAGE_WORD', "Imaj");
define('ATTACHMENT_WORD', "atachman");
define('REPEAT_WORD', "repete");
define('LIST_WORD', "Lis");
define('TYPE_WORD', "Kalite");
define('FIXED_WORD', "Fiks");
define('SCROLL_WORD', "Scroll");
define('SCROLLING_WORD', "defile");
define('INLINE_WORD', "Nan liy");
define('BLOCK_WORD', "Blòk");
define('COMPACT_WORD', "Kontra enfòmèl ant");
define('MARKER_WORD', "makè");
define('TABLE_WORD', "Table itilizatè");
define('XX_SMALL_WORD', "xx-small");
define('X_SMALL_WORD', "xx-small");
define('SMALL_WORD', "xx-small");
define('MEDIUM_WORD', "mwayen");
define('LARGE_WORD', "gwo");
define('X_LARGE_WORD', "x-gwo");
define('XX_LARGE_WORD', "xx-gwo");
define('SMALLER_WORD', "pi piti");
define('LARGER_WORD', "pi gwo");
define('NO_WRAP_WORD', "Pa gen vlope");
define('PRE_WORD', "pre");
define('PRE_LINE_WORD', "Pre-Line");
define('PRE_WRAP_WORD', "Pre-vlope");
define('POINTER_WORD', "Pointer");
define('CROSSHAIR_WORD', "vizeur");
define('DEFAULT_WORD', "default");
define('WAIT_WORD', "rete tann");
define('HELP_WORD', "Ede");
define('ALIAS_WORD', "Alyas");
define('CELL_WORD', "Pòtab");
define('COPY_WORD', "Kopi");
define('RENAME_WORD', "Chanje non");
define('MOVE_WORD', "Deplase");
define('ASSIGN_WORD', "bay");
define('PROGRESS_WORD', "Pwogrè");
define('HIDDEN_WORD', "kache");
define('DOTTED_WORD', "pwentiye");
define('DASHED_WORD', "an tirè");
define('SOLID_WORD', "solid");
define('DOUBLE_WORD', "Double");
define('GROOVE_WORD', "Groove");
define('RIDGE_WORD', "Ridge");
define('OUTSET_WORD', "kòmansman");
define('COLLAPSE_WORD', "Haiti");
define('SEPARATE_WORD', "Separe");
define('MIN_WORD', "Min");
define('MAX_WORD', "Max");
define('VISIBLE_WORD', "vizib");
define('BOTH_WORD', "tou de");
define('STATIC_WORD', "Anime");
define('SCALE_WORD', "echèl");
define('COVER_WORD', "Kouvri");
define('CONTAIN_WORD', "gen ladan");
define('DISC_WORD', "Ni Plak Zo Rèldo");
define('CIRCLE_WORD', "Fè yon ti wonn");
define('SQUARE_WORD', "Square");
define('DECIMAL_WORD', "desimal");
define('HEBREW_WORD', "Hebrew");
define('ARMENIAN_WORD', "armenian");
define('GORGIAN_WORD', "georgian");
define('INSIDE_WORD', "Anndan");
define('OUTSIDE_WORD', "Deyò");
define('CLASS_WORD', "Gwoup");
define('SUBCLASS_WORD', "souklas");
define('ID_WORD', "itilizatè ID");
define('CUSTOM_WORD', "Custom");
define('_NONE_WORD', "-none-");
define('ADD_WORD', "ajoute");
define('OWNER_WORD', "Mèt");
define('AUTHOR_WORD', "otè");
define('COPYRIGHT_WORD', "Copyright");
define('LANGUAGE_WORD', "Lang");
define('ABSTRACT_WORD', "Abstract");
define('KEYWORDS_WORD', "Keywords");
define('SUBJECT_WORD', "sijè");
define('ROBOTS_WORD', "robo");
define('INDEX_WORD', "Index");
define('FOLLOW_WORD', "swiv");
define('REVISIT_WORD', "revize");
define('DAYS_WORD', "jou");
define('OR_WORD', "Erè");
define('OR_CAP_WORD', "OSWA");
define('TO_WORD', "Auto");
define('CLICK_WORD', "Klike sou");
define('PAGE_WORD', "paj");
define('PAGE_1ST_CAP_WORD', "Page");
define('CONTENT_WORD', "Content");
define('DELETED_WORD', "efase");
define('BACKUP_WORD', "sovgad");
define('RESTORE_WORD', "renmèt");
define('REMOVE_WORD', "Retire");
define('CLOSE_WORD', "Close");
define('INSTALL_WORD', "enstale");
define('ADMIN_WORD', "Admin");
define('POWER_USER_WORD', "Pouvwa Itilizatè");
define('USER_WORD', "Pouvwa Itilizatè");
define('RESTRICTED_WORD', "Restricted");
define('BLOGGER_WORD', "Blogger");
define('RECIPIENT_WORD', "Moun Kap resevwa Asistans");
define('READING_WORD', "Lekti");
define('PARSING_WORD', "analyse");
define('RECALL_WORD', "Rapèl");
define('OPTION_WORD', "opsyon");
define('VALUE_WORD', "valè");
define('MOBILE_WORD', "Mobile");
define('TRANSPARENT_WORD', "transparan");
define('SOURCE_WORD', "sous");
define('CONDENSED_WORD', "kondanse");
define('ULTRA_CONDENSED_WORD', "Ultra-kondanse");
define('EXTRA_CONDENSED_WORD', "Ekstra kondanse");
define('SEMI_WORD', "Semi-kondanse");
define('EXPANDED_WORD', "elaji");
define('SEMI_EXPANDED_WORD', "Semi-Elaji");
define('EXTRA_EXPANDED_WORD', "Ekstra Elaji");
define('ULTRA_EXPANDED_WORD', "Ultra-Elaji");
define('INDENT_WORD', "indent");
define('BUILDING_WORD', "Building");
define('STYLE_SHEET_WORD', "fèy style");
define('TITLE_WORD', "Tit");
define('REFRESH_WORD', "Refresh");
define('FOLDER_WORD', "katab");
define('DOWNLOAD_WORD', "download");

define('QUERY_READY_TO_SEND', "Sijè rechèch pare yo voye ...");
define('QUERY_SENT', "rekèt voye");
define('QUERY_COMPLETE', "rekèt konplè");
define('QUERY_COMPLETE_NO_RECORD_FOUND', "Sijè rechèch konplè. Pa gen dosye yo te jwenn.");
define('SELF_NORMAL', "Self (nòmal)");
define('NEW_WINDOW', "nouvo fenèt");
define('NAMED_FRAME', "Yo te rele Frame");
define('ENTER_FRAME_NAME', "antre nan non ankadreman");
define('TEXT_ALIGNMENT', "Tèks armonizasyon");
define('_NOT_SELECTED_', "Wouch! Ou bliye chwazi yon paj ak / oswa yon Plugin.");
define('_NOT_SET_', "-pa mete-");
define('_NOT_ASSIGNED_', "-pa assigned-");
define('LETTER_SPACING', "lèt ekarteman");
define('SMALL_CAPS', "Ti Caps");
define('MOUSE_OUT', "Nòmal (soti sourit)");
define('MOUSE_OVER', "Hover (sourit lòt bò a)");
define('FONT_SIZE', "font size");
define('BOX_SHADOW', "Box lonbraj");
define('BACKGROUND_COLOR', "Top Nivo Jan nou koumanse Koulè");
define('BORDER_COLOR', "Top Nivo blòk Border Koulè");
define('BORDER_STYLE', "Border Style");
define('HORIZONTAL_OFFSET', "Kouche plat Offset");
define('VERTICAL_OFFSET', "vètikal Offset");
define('TEXT_TOP', "Tèks Top");
define('TEXT_BOTTOM', "Tèks anba");
define('VERTICAL_ALIGN', "vètikal align");
define('LINE_HEIGHT', "liy Tay");
define('SORT_ORDER', "Mete Gwoup Sòt Lòd");
define('LAST_REVISED', "Dènye Révisé");
define('GENERATE_PASSWORD', "Jenere Modpas");
define('CHANGE_PASSWORD', "Chanje Modpas");
define('ACCESS_LEVELS', "Chanje nivo aksè ...");
define('ADD_USER', "Ou dwe chwazi yon tab premye yo ajoute yon itilizatè yo.");
define('MODIFY_USER', "modifye Itilizatè");
define('DELETE_USER', "Èske ou sèten ou vle efase itilizatè a");
define('NEW_PASSWORD', "Nouvo modpas");
define('SELECT_ALL', "Seleksyone tout");
define('CLEAR_ALL', "Verouyaj Klè tout Custom CSS Klas");
define('TO_TRY_AGAIN', "eseye ankò.");
define('AND_TRY_AGAIN', "epi eseye ankò.");
define('NEW_FILE', "nouvo File");
define('NEW_FOLDER', "nouvo Dosye");
define('FOLDER_NAME', "Non dosye");
define('SHOW_BACKUP_FILES', "Montre sovgad Files");
define('EDIT_MENU_ITEMS_MEGA_MENU', "Mega Menu");
define('MEGA_MENU_MANAGE_BTN', "Jere Meni Mega");
define('MEGA_MENU_EDIT_SELECT_HEADING', "Edit Meni Mega");
define('MEGA_MENU_CREATE_HEADING', "Kreye mega Menu");
define('MEGA_MENU_BACK_BTN', "Retounen nan Edit Atik Menu");
define('MEGA_MENU_PAGE_ALREADY_EXISTS_1_ERR', "Mega meni");
define('MEGA_MENU_PAGE_ALREADY_EXISTS_2_ERR', "deja egziste. Tanpri antre nan yon non diferan oswa modifye yon sèl la ki deja egziste.");
define('MENU_WORD', "Menu");
define('MENU_ITEM', "atik meni");
define('MANAGE_CUSTOM_BORDER_AREA_ADD_AREA_BTN', "Ajoute Yon lòt Zòn Border");
define('MANAGE_CUSTOM_BORDER_AREA_BACK_BTN', "Retounen nan Jere Zòn Border");
define('MANAGE_HEAD_BACK_BTN', "Retounen nan Edit Head Kòd");
define('MANAGE_HEAD_MANAGE_BTN', "Jere Custom Head Kòd");
define('OPTIONS_ENABLE_CSS_MENUS', "Pèmèt CSS Meni");
define('OPTIONS_ENABLE_JS_MENUS', "Pèmèt JavaScript Meni");
define('EDITOR_BACK_TO_SELECT', "Retounen nan Chwazi");
define('COPY_STYLE_TO_MOBILE_BACK_TO_EDIT_CSS_SELECT_BTN', "Retounen nan Edit Styles Chwazi");
define('EDIT_STYLE_SHEET_ATT_BTN', "Jere Style Atribi Fèy");
define('MANAGE_STYLE_SHEET_ATT_HEADING', "Jere Style Atribi Fèy");
define('MANAGE_STYLE_SHEET_ATT_BACK_TO_EDIT_CSS_SELECT', "Retounen nan Edit CSS Chwazi");
define('MANAGE_STYLE_SHEET_ATT_CHARSET', "charset");
define('MANAGE_STYLE_SHEET_ATT_IMPORT', "Import");
define('MANAGE_STYLE_SHEET_ATT_MEDIA', "Media");
define('MANAGE_STYLE_SHEET_ATT_MEDIA_TYPE', "Media Kalite");
define('MANAGE_STYLE_SHEET_ATT_MEDIA_FEATURE', "Media Feature");
define('MANAGE_STYLE_SHEET_ATT_MEDIA_FEATURE_VALUE', "Media Feature Valè");
define('MANAGE_STYLE_SHEET_ATT_ADD_STYLE_SHEET', "Ajoute Style Fèy");
define('MANAGE_STYLE_SHEET_ATT_DELETE_STYLE_SHEET', "Debarase m de Style Fèy");
define('MANAGE_STYLE_SHEET_ATT_RENAME_STYLE_SHEET', "Chanje non Style Fèy");
define('MANAGE_STYLE_SHEET_ATT_NEW_NAME', "nouvo Non");
define('MANAGE_STYLE_SHEET_ATT_NEW_DESC', "nouvo Deskripsyon");
define('MANAGE_STYLE_SHEET_ATT_SAVE_SUCCESS_MSG', "Ou atribi dra style yo te sove.");
define('MANAGE_STYLE_SHEET_ATT_SAVE_ERROR_ERR', "Te gen yon erè ekonomize ou atribi dra style.");
define('MANAGE_STYLE_SHEET_ATT_ADD_SUCCESS_MSG', "te fèy style ou te sove.");
define('MANAGE_STYLE_SHEET_ATT_ADD_SHEET_ALREADY_EXISTS_ERR', "Sa fèy style deja egziste. Tanpri, chwazi yon non diferan epi eseye ankò");
define('MANAGE_STYLE_SHEET_ATT_ADD_ERROR_ERR', "Te gen yon erè pandan l ajoute fèy style ou.");
define('MANAGE_STYLE_SHEET_ATT_DELETE_CONFIRM_MSG', "Èske ou sèten ou vle efase nan");
define('MANAGE_STYLE_SHEET_ATT_DELETE_SUCCESS_MSG', "te fèy style ou efase.");
define('MANAGE_STYLE_SHEET_ATT_DELETE_ERROR_ERR', "Te gen yon erè efase fèy style ou.");
define('MANAGE_STYLE_SHEET_ATT_RENAME_SUCCESS_MSG', "te fèy style ou te chanje non.");
define('MANAGE_STYLE_SHEET_ATT_RENAME_ERROR_ERR', "Te gen yon erè lòt non fèy style ou.");
define('NOT_WORD', "Pa");
define('ONLY_WORD', "Se sèlman");
define('ALL_WORD', "tout");
define('PRINT_WORD', "Ekri an lèt detache");
define('SCREEN_WORD', "ekran");
define('SPEECH_WORD', "Lapawòl");
define('AND_WORD', "ak");
define('DESKTOP_WORD', "Desktop");
define('MIN_WIDTH', "Min Lajè");
define('MAX_WIDTH', "Max Lajè");
define('MIN_HEIGHT', "Min Tay");
define('MAX_HEIGHT', "Max Tay");
define('GET_MORE_PLUGINS_BTN', "Jwenn Plis Plugins");
define('GET_MORE_TEMPLATES_BTN', "Jwenn Plis Templates");
define('MANAGE_STYLE_SHEET_ATT_EXCLUDE_FROM_LIST', "Eskli nan lis default");
define('MANAGE_STYLE_SHEET_ATT_SHOW_CUSTOM_STYLES', "Montre estil koutim");
define('MANAGE_STYLE_SHEET_ATT_SHOW_ALL', "Montre tout dra style");
define('UPLOAD_TEMPLATE_UPLOAD_TEMPLATE_COMPLETE', "Modèl enstalasyon se konplè.");
define('CREATE_PAGE_SELECT_CREATE_PLUGIN_GROUP', "Kreye tout paj plugin pou gwoup plugin sa a");
define('CREATE_PAGE_SELECT_ALREADY_EXISTS_ERR', "endefini");
define('MANAGE_STYLE_SHEET_SET_SORT_ORDER', "Mete Style Fèy Sòt Lòd");
define('MANAGE_STYLE_SHEET_NAME_DESCRIPTION', "Style Fèy / Deskripsyon");
define('EDIT_CSS_SHOW_ALL_CLASSES', "Montre tout klas");
define('EDIT_CSS_MENU_STYLES_OMIT_ADJACENT_BORDERS', "O&lt;br&gt;m&lt;br&gt;i&lt;br&gt;t&lt;br&gt;&lt;br&gt;A&lt;br&gt;d&lt;br&gt;j&lt;br&gt;a&lt;br&gt;c&lt;br&gt;e&lt;br&gt;n&lt;br&gt;t&lt;br&gt;&lt;br&gt;B&lt;br&gt;o&lt;br&gt;r&lt;br&gt;d&lt;br&gt;e&lt;br&gt;r&lt;br&gt;s");
define('EDIT_CSS_MENU_PARAMETERS_SUB_MENU_1_SIZE_PADDING', "Gwoup Menu 1 Item gwosè ak ranbouraj");
define('EDIT_CSS_MENU_PARAMETERS_SUB_MENU_2_SIZE_PADDING', "Gwoup Menu 2 Item gwosè ak ranbouraj");
define('EDIT_CSS_MENU_PARAMETERS_ITEM_SPACING', "Item ekarteman");
define('EDIT_CSS_MENU_STYLES_DOWN', "Down (bouton desann)");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_BACKGROUND_COLOR', "Gwoup Nivo 1 Jan nou koumanse Koulè");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_BACKGROUND_COLOR', "endefini");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_ITEM_BORDER_COLOR', "Gwoup Nivo 1 Item Border Koulè");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_ITEM_BORDER_COLOR', "Gwoup Nivo 2 Item Border Koulè");
define('EDIT_CSS_MENU_STYLES_PARAMS_NOT_SET_ERR_1', "paramèt meni CSS pa te mete. tanpri klike");
define('EDIT_CSS_MENU_STYLES_PARAMS_NOT_SET_ERR_2', "yo konfigirasyon paramèt yo meni CSS");
define('BORDER_RADIUS', "Border Reyon");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1', "Gwoup Nivo 1");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2', "Gwoup Nivo 2");
define('EDIT_MENU_ITEMS_ADD_BEFORE_SAVE_NEW_MSG', "Ou gen nouvo atik ki pa te sove. Tanpri delivre sa atik avan ou ajoute yon nouvo.");
define('EDIT_CSS_MENU_STYLES_SHADOW_COLOR', "lonbraj Koulè");
define('EDIT_CSS_MENU_STYLES_HOVER_ON_DOWN', "Hover sou desann");
define('EDIT_CSS_FOREGROUND_OPAQUE_1', "plan");
define('EDIT_CSS_FOREGROUND_OPAQUE_2', "opak");
define('ADMIN_FUNCTION_SELECT_RESTRICT_BLOG_PAGE_EDITING_ACCESS_BTN', "Mete restriksyon sou Blog Page Korije Aksè");
define('RESTRICT_BLOG_EDITING_HEADING', "Mete restriksyon sou Aksè nan Blogging pou Blogueurs");
define('USERS_WORD', "itilizatè yo");
define('PUBLISHED_WORD', "pibliye");
define('DRAFT_WORD', "Draft");
define('ADD_ALL', "ajoute tout");
define('BLOG_PAGE', "Blog Page");
define('EDIT_CSS_FLEX', "Flex");
define('EDIT_CSS_INLINE_FLEX', "Inline-Flex");
define('EDIT_CSS_CONTENT_TEXT', "Content Tèks");
define('EDIT_CSS_JUSTIFY_CONTENT', "jistifye avantou");
define('EDIT_CSS_SET_CONTENT_BLANK', "Mete avantou Blank");
define('EDIT_CSS_FLEX_START', "Flex Start");
define('EDIT_CSS_FLEX_END', "Flex Fen");
define('EDIT_CSS_SPACE_BETWEEN', "Espas Ant");
define('EDIT_CSS_SPACE_AROUND', "Espas Anviwon");
define('EDIT_CSS_SET_DISPLAY_FLEX', "Mete Display Flex");
define('EDIT_CSS_WRAP_REVERSE', "vlope Fèy");
define('EDIT_CSS_ROW_REVERSE', "ranje Fèy");
define('EDIT_CSS_COLUMN_REVERSE', "endefini");
define('EDIT_CSS_DISPLAY_SET_TO_FLEX', "te atribi nan ekspozisyon te mete nan &#39;flechir&#39;.");
define('EDIT_CSS_CONTENT_SET_TO_BLANK', "fisèl la &#39;-blank-&#39; di compliler nan CSS fisèl yo mete kontni an nan &#39;&#39;.");
define('WRAP_WORD', "vlope");
define('CAPITALIZE_WORD', "kapitalize");
define('UPPERCASE_WORD', "majuskul");
define('LOWERCASE_WORD', "miniskil");
define('STRING_WORD', "chèn");
define('ATTRIBUTE_WORD', "atribi");
define('COUNTER_WORD', "Counter");
define('TRANSITION_WORD', "tranzisyon");
define('PROPERTY_WORD', "pwopriyete");
define('DURATION_WORD', "endefini");
define('DELAY_WORD', "reta");
define('EASE_WORD', "fasilite");
define('LINEAR_WORD', "lineyè");
define('BASIS_WORD', "baz");
define('GROW_WORD', "Grandi");
define('SHRINK_WORD', "Doktè Moun Fou");
define('LENGTH_WORD', "Length");
define('DIRECTION_WORD', "Direksyon");
define('ROW_WORD', "ranje");
define('COLUMN_WORD', "kolòn");
define('TEXT_TRANSFORM', "Tèks transfòme");
define('OPEN_QUOTE', "louvri Quote");
define('CLOSE_QUOTE', "Close Quote");
define('NO_OPEN_QUOTE', "Se pa Quote Louvri");
define('NO_CLOSE_QUOTE', "Se pa Close Quote");
define('TIMING_FUNCTION', "distribisyon Fonksyon");
define('EASE_IN', "fasilite Nan");
define('EASE_OUT', "fasilite soti");
define('EASE_IN_OUT', "Fasilite Nan ak Andeyò");
define('WIDTH_AND_HEIGHT', "Lajè ak wotè");
define('EDIT_CSS_ENTER_STR_MSG', "Antre nan tèks la yo itilize kòm kontni nan jaden yo onglet D &#39;tèks, oswa kite vid yo mete tèks nan vid.");
define('EDIT_CSS_ENTER_URL_MSG', "Antre nan URL la nan jaden an Contenu opinyon tèks.");
define('EDIT_CSS_ENTER_ATTR_MSG', "Antre nan HTML objè attribite a, sa vle &#39;href&#39; oswa &#39;Non&#39; nan jaden yo onglet D &#39;tèks.");
define('IMPORTANT_HEADING', "Jere Atribi CSS enpòtan");
define('MANAGE_PAGE_ACCESS_NO_LOGIN_FIELDS_IN_TABLE_ERR', "Table ki manke jaden yo user-login. Si ou vle sèvi ak tablo sa a pou gen aksè itilizatè, ou dwe premye ajoute jaden user-login sou tab sa a lè l sèvi avèk &#39;Ajoute Utilisateur Connexion Jaden nan tab&#39; bouton.");
define('THRU_WORD', "rive");
define('OF_WORD', "nan");
define('SHOWING_RECORDS', "Showing dosye");
define('FIRST_NAME', "Prenon");
define('LAST_NAME', "Siyati");
define('EDIT_CSS_MENU_PARAMETERS_LATCH_EXPANDED_ON_DOWN', "Obtenir Elaji maren sou atik desann");
define('RADIAL_WORD', "radial");
define('ANGLE_WORD', "ang");
define('DEGREES_WORD', "degre");
define('BACKGROUND_GRADIENT', "jan nou koumanse Gradyan");
define('TOP_TO_BOTTOM', "Anwo jouk anba");
define('BOTTOM_LEFT_TO_TOP_RIGHT', "Anba Left to Top Dwa");
define('LEFT_TO_RIGHT', "endefini");
define('TOP_LEFT_TO_BOTTOM_RIGHT', "Top kite yo anba Dwa");
define('BOTTOM_TO_TOP', "Anba nan tèt");
define('TOP_RIGHT_TO_BOTTOM_LEFT', "Top Dwa a anba Left");
define('RIGHT_TO_LEFT', "Dwa a Left");
define('BOTTOM_RIGHT_TO_TOP_LEFT', "Anba Dwa nan tèt Left");
define('EDIT_CSS_MENU_PARAMETERS_SUB_1_MENU_POSITIONING', "Sub Menu 1 Layout ak Pozisyon");
define('EDIT_CSS_MENU_PARAMETERS_SUB_2_MENU_POSITIONING', "Sub Menu 2 Layout ak Pozisyon");
define('HOVER_WORD', "Hover");
define('DOWN_WORD', "Desann");
define('EDIT_CSS_MENU_PARAMETERS_BASE_Z_INDEX', "Sèvi Z-Index");
define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_1', "Pa gen okenn grefon anba kategori a");
define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_2', "Klike sou");
define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_3', "jwenn yon Plugin nan kategori sa a.");
define('MAIN_MENU_MANAGE_MY_ACCOUNT_BTN', "Jere kont mwen");
define('MAIN_MENU_SHOW_PASSWORD_RESET_MSG', "Modpas ou te mete ajou ak modpas tanporè a. Li rekòmande ke ou chanje modpas ou a somethitng pi fasil yo tape ak sonje, ak Lè sa a, magazen nouvo modpas ou nan yon kote ki an sekirite. Ou vle chanje modpas ou an kounye a?");
define('MANAGE_USERS_CHANGE_MY_PASSWORD', "Chanje Modpas mwen");
define('MANAGE_USERS_MODIFY_MY_ACCOUNT', "Modifye kont mwen an");
define('STICKY_WORD', "Kolye");
define('EDIT_CSS_SETUP_STICKY_HEADER_BTN', "Enstalasyon Pou Heady Sticky");
define('EDIT_CSS_LOAD_STICKY_HEADERS_ALERT_MSG', "Nou pral kounye a chaje estil ak anviwònman ki pral lakòz header nan paj wèb ou nan &#39;bwa&#39; nan tèt la nan fenèt navigatè ou a.");
define('EDIT_CSS_LOAD_STICKY_HEADERS_COMPLETE_MSG', "Lento ou pral kounye a bwa nan tèt la nan fenèt navigatè a.");
define('UPLOAD_TEMPLATE_COPYING_FONTS_MSG', "Kopi polis ...");
define('MANAGE_MENUS_COPY_MENU_BTN', "Kopi meni an");
define('MANAGE_MENUS_COPY_MENU_ITEMS_TO_MOBILE_BTN', "Kopi Atik Menu Desktop nan mobil");
define('MANAGE_MENUS_CREATE_NEW', "New Menu");
define('MANAGE_MENUS_COPY_MENU_CONFIRM_1_MSG', "Èske ou sèten ou vle kopye a");
define('MANAGE_MENUS_COPY_MENU_CONFIRM_2_MSG', "meni nan la");
define('MANAGE_MENUS_COPY_MENU_CONFIRM_3_MSG', "meni?");
define('MANAGE_MENUS_COPY_MENU_ITEMS_CONFIRM_2_MSG', "meni atik nan la");
define('TO_1ST_CAP_WORD', "Pou");
define('FROM_WORD', "Soti nan");
?>